'''OpenGL extension EXT.vertex_shader

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_vertex_shader'
_DEPRECATED = False
GL_VERTEX_SHADER_EXT = constant.Constant( 'GL_VERTEX_SHADER_EXT', 0x8780 )
glget.addGLGetConstant( GL_VERTEX_SHADER_EXT, (1,) )
GL_VERTEX_SHADER_BINDING_EXT = constant.Constant( 'GL_VERTEX_SHADER_BINDING_EXT', 0x8781 )
glget.addGLGetConstant( GL_VERTEX_SHADER_BINDING_EXT, (1,) )
GL_OP_INDEX_EXT = constant.Constant( 'GL_OP_INDEX_EXT', 0x8782 )
GL_OP_NEGATE_EXT = constant.Constant( 'GL_OP_NEGATE_EXT', 0x8783 )
GL_OP_DOT3_EXT = constant.Constant( 'GL_OP_DOT3_EXT', 0x8784 )
GL_OP_DOT4_EXT = constant.Constant( 'GL_OP_DOT4_EXT', 0x8785 )
GL_OP_MUL_EXT = constant.Constant( 'GL_OP_MUL_EXT', 0x8786 )
GL_OP_ADD_EXT = constant.Constant( 'GL_OP_ADD_EXT', 0x8787 )
GL_OP_MADD_EXT = constant.Constant( 'GL_OP_MADD_EXT', 0x8788 )
GL_OP_FRAC_EXT = constant.Constant( 'GL_OP_FRAC_EXT', 0x8789 )
GL_OP_MAX_EXT = constant.Constant( 'GL_OP_MAX_EXT', 0x878A )
GL_OP_MIN_EXT = constant.Constant( 'GL_OP_MIN_EXT', 0x878B )
GL_OP_SET_GE_EXT = constant.Constant( 'GL_OP_SET_GE_EXT', 0x878C )
GL_OP_SET_LT_EXT = constant.Constant( 'GL_OP_SET_LT_EXT', 0x878D )
GL_OP_CLAMP_EXT = constant.Constant( 'GL_OP_CLAMP_EXT', 0x878E )
GL_OP_FLOOR_EXT = constant.Constant( 'GL_OP_FLOOR_EXT', 0x878F )
GL_OP_ROUND_EXT = constant.Constant( 'GL_OP_ROUND_EXT', 0x8790 )
GL_OP_EXP_BASE_2_EXT = constant.Constant( 'GL_OP_EXP_BASE_2_EXT', 0x8791 )
GL_OP_LOG_BASE_2_EXT = constant.Constant( 'GL_OP_LOG_BASE_2_EXT', 0x8792 )
GL_OP_POWER_EXT = constant.Constant( 'GL_OP_POWER_EXT', 0x8793 )
GL_OP_RECIP_EXT = constant.Constant( 'GL_OP_RECIP_EXT', 0x8794 )
GL_OP_RECIP_SQRT_EXT = constant.Constant( 'GL_OP_RECIP_SQRT_EXT', 0x8795 )
GL_OP_SUB_EXT = constant.Constant( 'GL_OP_SUB_EXT', 0x8796 )
GL_OP_CROSS_PRODUCT_EXT = constant.Constant( 'GL_OP_CROSS_PRODUCT_EXT', 0x8797 )
GL_OP_MULTIPLY_MATRIX_EXT = constant.Constant( 'GL_OP_MULTIPLY_MATRIX_EXT', 0x8798 )
GL_OP_MOV_EXT = constant.Constant( 'GL_OP_MOV_EXT', 0x8799 )
GL_OUTPUT_VERTEX_EXT = constant.Constant( 'GL_OUTPUT_VERTEX_EXT', 0x879A )
GL_OUTPUT_COLOR0_EXT = constant.Constant( 'GL_OUTPUT_COLOR0_EXT', 0x879B )
GL_OUTPUT_COLOR1_EXT = constant.Constant( 'GL_OUTPUT_COLOR1_EXT', 0x879C )
GL_OUTPUT_TEXTURE_COORD0_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD0_EXT', 0x879D )
GL_OUTPUT_TEXTURE_COORD1_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD1_EXT', 0x879E )
GL_OUTPUT_TEXTURE_COORD2_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD2_EXT', 0x879F )
GL_OUTPUT_TEXTURE_COORD3_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD3_EXT', 0x87A0 )
GL_OUTPUT_TEXTURE_COORD4_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD4_EXT', 0x87A1 )
GL_OUTPUT_TEXTURE_COORD5_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD5_EXT', 0x87A2 )
GL_OUTPUT_TEXTURE_COORD6_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD6_EXT', 0x87A3 )
GL_OUTPUT_TEXTURE_COORD7_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD7_EXT', 0x87A4 )
GL_OUTPUT_TEXTURE_COORD8_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD8_EXT', 0x87A5 )
GL_OUTPUT_TEXTURE_COORD9_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD9_EXT', 0x87A6 )
GL_OUTPUT_TEXTURE_COORD10_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD10_EXT', 0x87A7 )
GL_OUTPUT_TEXTURE_COORD11_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD11_EXT', 0x87A8 )
GL_OUTPUT_TEXTURE_COORD12_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD12_EXT', 0x87A9 )
GL_OUTPUT_TEXTURE_COORD13_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD13_EXT', 0x87AA )
GL_OUTPUT_TEXTURE_COORD14_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD14_EXT', 0x87AB )
GL_OUTPUT_TEXTURE_COORD15_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD15_EXT', 0x87AC )
GL_OUTPUT_TEXTURE_COORD16_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD16_EXT', 0x87AD )
GL_OUTPUT_TEXTURE_COORD17_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD17_EXT', 0x87AE )
GL_OUTPUT_TEXTURE_COORD18_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD18_EXT', 0x87AF )
GL_OUTPUT_TEXTURE_COORD19_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD19_EXT', 0x87B0 )
GL_OUTPUT_TEXTURE_COORD20_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD20_EXT', 0x87B1 )
GL_OUTPUT_TEXTURE_COORD21_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD21_EXT', 0x87B2 )
GL_OUTPUT_TEXTURE_COORD22_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD22_EXT', 0x87B3 )
GL_OUTPUT_TEXTURE_COORD23_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD23_EXT', 0x87B4 )
GL_OUTPUT_TEXTURE_COORD24_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD24_EXT', 0x87B5 )
GL_OUTPUT_TEXTURE_COORD25_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD25_EXT', 0x87B6 )
GL_OUTPUT_TEXTURE_COORD26_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD26_EXT', 0x87B7 )
GL_OUTPUT_TEXTURE_COORD27_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD27_EXT', 0x87B8 )
GL_OUTPUT_TEXTURE_COORD28_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD28_EXT', 0x87B9 )
GL_OUTPUT_TEXTURE_COORD29_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD29_EXT', 0x87BA )
GL_OUTPUT_TEXTURE_COORD30_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD30_EXT', 0x87BB )
GL_OUTPUT_TEXTURE_COORD31_EXT = constant.Constant( 'GL_OUTPUT_TEXTURE_COORD31_EXT', 0x87BC )
GL_OUTPUT_FOG_EXT = constant.Constant( 'GL_OUTPUT_FOG_EXT', 0x87BD )
GL_SCALAR_EXT = constant.Constant( 'GL_SCALAR_EXT', 0x87BE )
GL_VECTOR_EXT = constant.Constant( 'GL_VECTOR_EXT', 0x87BF )
GL_MATRIX_EXT = constant.Constant( 'GL_MATRIX_EXT', 0x87C0 )
GL_VARIANT_EXT = constant.Constant( 'GL_VARIANT_EXT', 0x87C1 )
GL_INVARIANT_EXT = constant.Constant( 'GL_INVARIANT_EXT', 0x87C2 )
GL_LOCAL_CONSTANT_EXT = constant.Constant( 'GL_LOCAL_CONSTANT_EXT', 0x87C3 )
GL_LOCAL_EXT = constant.Constant( 'GL_LOCAL_EXT', 0x87C4 )
GL_MAX_VERTEX_SHADER_INSTRUCTIONS_EXT = constant.Constant( 'GL_MAX_VERTEX_SHADER_INSTRUCTIONS_EXT', 0x87C5 )
glget.addGLGetConstant( GL_MAX_VERTEX_SHADER_INSTRUCTIONS_EXT, (1,) )
GL_MAX_VERTEX_SHADER_VARIANTS_EXT = constant.Constant( 'GL_MAX_VERTEX_SHADER_VARIANTS_EXT', 0x87C6 )
glget.addGLGetConstant( GL_MAX_VERTEX_SHADER_VARIANTS_EXT, (1,) )
GL_MAX_VERTEX_SHADER_INVARIANTS_EXT = constant.Constant( 'GL_MAX_VERTEX_SHADER_INVARIANTS_EXT', 0x87C7 )
glget.addGLGetConstant( GL_MAX_VERTEX_SHADER_INVARIANTS_EXT, (1,) )
GL_MAX_VERTEX_SHADER_LOCAL_CONSTANTS_EXT = constant.Constant( 'GL_MAX_VERTEX_SHADER_LOCAL_CONSTANTS_EXT', 0x87C8 )
glget.addGLGetConstant( GL_MAX_VERTEX_SHADER_LOCAL_CONSTANTS_EXT, (1,) )
GL_MAX_VERTEX_SHADER_LOCALS_EXT = constant.Constant( 'GL_MAX_VERTEX_SHADER_LOCALS_EXT', 0x87C9 )
glget.addGLGetConstant( GL_MAX_VERTEX_SHADER_LOCALS_EXT, (1,) )
GL_MAX_OPTIMIZED_VERTEX_SHADER_INSTRUCTIONS_EXT = constant.Constant( 'GL_MAX_OPTIMIZED_VERTEX_SHADER_INSTRUCTIONS_EXT', 0x87CA )
glget.addGLGetConstant( GL_MAX_OPTIMIZED_VERTEX_SHADER_INSTRUCTIONS_EXT, (1,) )
GL_MAX_OPTIMIZED_VERTEX_SHADER_VARIANTS_EXT = constant.Constant( 'GL_MAX_OPTIMIZED_VERTEX_SHADER_VARIANTS_EXT', 0x87CB )
glget.addGLGetConstant( GL_MAX_OPTIMIZED_VERTEX_SHADER_VARIANTS_EXT, (1,) )
GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCAL_CONSTANTS_EXT = constant.Constant( 'GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCAL_CONSTANTS_EXT', 0x87CC )
glget.addGLGetConstant( GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCAL_CONSTANTS_EXT, (1,) )
GL_MAX_OPTIMIZED_VERTEX_SHADER_INVARIANTS_EXT = constant.Constant( 'GL_MAX_OPTIMIZED_VERTEX_SHADER_INVARIANTS_EXT', 0x87CD )
GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCALS_EXT = constant.Constant( 'GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCALS_EXT', 0x87CE )
glget.addGLGetConstant( GL_MAX_OPTIMIZED_VERTEX_SHADER_LOCALS_EXT, (1,) )
GL_VERTEX_SHADER_INSTRUCTIONS_EXT = constant.Constant( 'GL_VERTEX_SHADER_INSTRUCTIONS_EXT', 0x87CF )
GL_VERTEX_SHADER_VARIANTS_EXT = constant.Constant( 'GL_VERTEX_SHADER_VARIANTS_EXT', 0x87D0 )
GL_VERTEX_SHADER_INVARIANTS_EXT = constant.Constant( 'GL_VERTEX_SHADER_INVARIANTS_EXT', 0x87D1 )
GL_VERTEX_SHADER_LOCAL_CONSTANTS_EXT = constant.Constant( 'GL_VERTEX_SHADER_LOCAL_CONSTANTS_EXT', 0x87D2 )
GL_VERTEX_SHADER_LOCALS_EXT = constant.Constant( 'GL_VERTEX_SHADER_LOCALS_EXT', 0x87D3 )
GL_VERTEX_SHADER_OPTIMIZED_EXT = constant.Constant( 'GL_VERTEX_SHADER_OPTIMIZED_EXT', 0x87D4 )
glget.addGLGetConstant( GL_VERTEX_SHADER_OPTIMIZED_EXT, (1,) )
GL_X_EXT = constant.Constant( 'GL_X_EXT', 0x87D5 )
GL_Y_EXT = constant.Constant( 'GL_Y_EXT', 0x87D6 )
GL_Z_EXT = constant.Constant( 'GL_Z_EXT', 0x87D7 )
GL_W_EXT = constant.Constant( 'GL_W_EXT', 0x87D8 )
GL_NEGATIVE_X_EXT = constant.Constant( 'GL_NEGATIVE_X_EXT', 0x87D9 )
GL_NEGATIVE_Y_EXT = constant.Constant( 'GL_NEGATIVE_Y_EXT', 0x87DA )
GL_NEGATIVE_Z_EXT = constant.Constant( 'GL_NEGATIVE_Z_EXT', 0x87DB )
GL_NEGATIVE_W_EXT = constant.Constant( 'GL_NEGATIVE_W_EXT', 0x87DC )
GL_ZERO_EXT = constant.Constant( 'GL_ZERO_EXT', 0x87DD )
GL_ONE_EXT = constant.Constant( 'GL_ONE_EXT', 0x87DE )
GL_NEGATIVE_ONE_EXT = constant.Constant( 'GL_NEGATIVE_ONE_EXT', 0x87DF )
GL_NORMALIZED_RANGE_EXT = constant.Constant( 'GL_NORMALIZED_RANGE_EXT', 0x87E0 )
GL_FULL_RANGE_EXT = constant.Constant( 'GL_FULL_RANGE_EXT', 0x87E1 )
GL_CURRENT_VERTEX_EXT = constant.Constant( 'GL_CURRENT_VERTEX_EXT', 0x87E2 )
GL_MVP_MATRIX_EXT = constant.Constant( 'GL_MVP_MATRIX_EXT', 0x87E3 )
GL_VARIANT_VALUE_EXT = constant.Constant( 'GL_VARIANT_VALUE_EXT', 0x87E4 )
GL_VARIANT_DATATYPE_EXT = constant.Constant( 'GL_VARIANT_DATATYPE_EXT', 0x87E5 )
GL_VARIANT_ARRAY_STRIDE_EXT = constant.Constant( 'GL_VARIANT_ARRAY_STRIDE_EXT', 0x87E6 )
GL_VARIANT_ARRAY_TYPE_EXT = constant.Constant( 'GL_VARIANT_ARRAY_TYPE_EXT', 0x87E7 )
GL_VARIANT_ARRAY_EXT = constant.Constant( 'GL_VARIANT_ARRAY_EXT', 0x87E8 )
GL_VARIANT_ARRAY_POINTER_EXT = constant.Constant( 'GL_VARIANT_ARRAY_POINTER_EXT', 0x87E9 )
GL_INVARIANT_VALUE_EXT = constant.Constant( 'GL_INVARIANT_VALUE_EXT', 0x87EA )
GL_INVARIANT_DATATYPE_EXT = constant.Constant( 'GL_INVARIANT_DATATYPE_EXT', 0x87EB )
GL_LOCAL_CONSTANT_VALUE_EXT = constant.Constant( 'GL_LOCAL_CONSTANT_VALUE_EXT', 0x87EC )
GL_LOCAL_CONSTANT_DATATYPE_EXT = constant.Constant( 'GL_LOCAL_CONSTANT_DATATYPE_EXT', 0x87ED )
glBeginVertexShaderEXT = platform.createExtensionFunction( 
'glBeginVertexShaderEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glBeginVertexShaderEXT() -> None',
argNames=(),
deprecated=_DEPRECATED,
)

glEndVertexShaderEXT = platform.createExtensionFunction( 
'glEndVertexShaderEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(),
doc='glEndVertexShaderEXT() -> None',
argNames=(),
deprecated=_DEPRECATED,
)

glBindVertexShaderEXT = platform.createExtensionFunction( 
'glBindVertexShaderEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glBindVertexShaderEXT(GLuint(id)) -> None',
argNames=('id',),
deprecated=_DEPRECATED,
)

glGenVertexShadersEXT = platform.createExtensionFunction( 
'glGenVertexShadersEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLuint, 
argTypes=(constants.GLuint,),
doc='glGenVertexShadersEXT(GLuint(range)) -> constants.GLuint',
argNames=('range',),
deprecated=_DEPRECATED,
)

glDeleteVertexShaderEXT = platform.createExtensionFunction( 
'glDeleteVertexShaderEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glDeleteVertexShaderEXT(GLuint(id)) -> None',
argNames=('id',),
deprecated=_DEPRECATED,
)

glShaderOp1EXT = platform.createExtensionFunction( 
'glShaderOp1EXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,),
doc='glShaderOp1EXT(GLenum(op), GLuint(res), GLuint(arg1)) -> None',
argNames=('op','res','arg1',),
deprecated=_DEPRECATED,
)

glShaderOp2EXT = platform.createExtensionFunction( 
'glShaderOp2EXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glShaderOp2EXT(GLenum(op), GLuint(res), GLuint(arg1), GLuint(arg2)) -> None',
argNames=('op','res','arg1','arg2',),
deprecated=_DEPRECATED,
)

glShaderOp3EXT = platform.createExtensionFunction( 
'glShaderOp3EXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glShaderOp3EXT(GLenum(op), GLuint(res), GLuint(arg1), GLuint(arg2), GLuint(arg3)) -> None',
argNames=('op','res','arg1','arg2','arg3',),
deprecated=_DEPRECATED,
)

glSwizzleEXT = platform.createExtensionFunction( 
'glSwizzleEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,constants.GLenum,constants.GLenum,constants.GLenum,),
doc='glSwizzleEXT(GLuint(res), GLuint(in), GLenum(outX), GLenum(outY), GLenum(outZ), GLenum(outW)) -> None',
argNames=('res','in','outX','outY','outZ','outW',),
deprecated=_DEPRECATED,
)

glWriteMaskEXT = platform.createExtensionFunction( 
'glWriteMaskEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLenum,constants.GLenum,constants.GLenum,constants.GLenum,),
doc='glWriteMaskEXT(GLuint(res), GLuint(in), GLenum(outX), GLenum(outY), GLenum(outZ), GLenum(outW)) -> None',
argNames=('res','in','outX','outY','outZ','outW',),
deprecated=_DEPRECATED,
)

glInsertComponentEXT = platform.createExtensionFunction( 
'glInsertComponentEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glInsertComponentEXT(GLuint(res), GLuint(src), GLuint(num)) -> None',
argNames=('res','src','num',),
deprecated=_DEPRECATED,
)

glExtractComponentEXT = platform.createExtensionFunction( 
'glExtractComponentEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glExtractComponentEXT(GLuint(res), GLuint(src), GLuint(num)) -> None',
argNames=('res','src','num',),
deprecated=_DEPRECATED,
)

glGenSymbolsEXT = platform.createExtensionFunction( 
'glGenSymbolsEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLuint, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLuint,),
doc='glGenSymbolsEXT(GLenum(datatype), GLenum(storagetype), GLenum(range), GLuint(components)) -> constants.GLuint',
argNames=('datatype','storagetype','range','components',),
deprecated=_DEPRECATED,
)

glSetInvariantEXT = platform.createExtensionFunction( 
'glSetInvariantEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,ctypes.c_void_p,),
doc='glSetInvariantEXT(GLuint(id), GLenum(type), c_void_p(addr)) -> None',
argNames=('id','type','addr',),
deprecated=_DEPRECATED,
)

glSetLocalConstantEXT = platform.createExtensionFunction( 
'glSetLocalConstantEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,ctypes.c_void_p,),
doc='glSetLocalConstantEXT(GLuint(id), GLenum(type), c_void_p(addr)) -> None',
argNames=('id','type','addr',),
deprecated=_DEPRECATED,
)

glVariantbvEXT = platform.createExtensionFunction( 
'glVariantbvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLbyteArray,),
doc='glVariantbvEXT(GLuint(id), GLbyteArray(addr)) -> None',
argNames=('id','addr',),
deprecated=_DEPRECATED,
)

glVariantsvEXT = platform.createExtensionFunction( 
'glVariantsvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLshortArray,),
doc='glVariantsvEXT(GLuint(id), GLshortArray(addr)) -> None',
argNames=('id','addr',),
deprecated=_DEPRECATED,
)

glVariantivEXT = platform.createExtensionFunction( 
'glVariantivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLintArray,),
doc='glVariantivEXT(GLuint(id), GLintArray(addr)) -> None',
argNames=('id','addr',),
deprecated=_DEPRECATED,
)

glVariantfvEXT = platform.createExtensionFunction( 
'glVariantfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLfloatArray,),
doc='glVariantfvEXT(GLuint(id), GLfloatArray(addr)) -> None',
argNames=('id','addr',),
deprecated=_DEPRECATED,
)

glVariantdvEXT = platform.createExtensionFunction( 
'glVariantdvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLdoubleArray,),
doc='glVariantdvEXT(GLuint(id), GLdoubleArray(addr)) -> None',
argNames=('id','addr',),
deprecated=_DEPRECATED,
)

glVariantubvEXT = platform.createExtensionFunction( 
'glVariantubvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLubyteArray,),
doc='glVariantubvEXT(GLuint(id), GLubyteArray(addr)) -> None',
argNames=('id','addr',),
deprecated=_DEPRECATED,
)

glVariantusvEXT = platform.createExtensionFunction( 
'glVariantusvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLushortArray,),
doc='glVariantusvEXT(GLuint(id), GLushortArray(addr)) -> None',
argNames=('id','addr',),
deprecated=_DEPRECATED,
)

glVariantuivEXT = platform.createExtensionFunction( 
'glVariantuivEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLuintArray,),
doc='glVariantuivEXT(GLuint(id), GLuintArray(addr)) -> None',
argNames=('id','addr',),
deprecated=_DEPRECATED,
)

glVariantPointerEXT = platform.createExtensionFunction( 
'glVariantPointerEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,constants.GLuint,ctypes.c_void_p,),
doc='glVariantPointerEXT(GLuint(id), GLenum(type), GLuint(stride), c_void_p(addr)) -> None',
argNames=('id','type','stride','addr',),
deprecated=_DEPRECATED,
)

glEnableVariantClientStateEXT = platform.createExtensionFunction( 
'glEnableVariantClientStateEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glEnableVariantClientStateEXT(GLuint(id)) -> None',
argNames=('id',),
deprecated=_DEPRECATED,
)

glDisableVariantClientStateEXT = platform.createExtensionFunction( 
'glDisableVariantClientStateEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,),
doc='glDisableVariantClientStateEXT(GLuint(id)) -> None',
argNames=('id',),
deprecated=_DEPRECATED,
)

glBindLightParameterEXT = platform.createExtensionFunction( 
'glBindLightParameterEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLuint, 
argTypes=(constants.GLenum,constants.GLenum,),
doc='glBindLightParameterEXT(GLenum(light), GLenum(value)) -> constants.GLuint',
argNames=('light','value',),
deprecated=_DEPRECATED,
)

glBindMaterialParameterEXT = platform.createExtensionFunction( 
'glBindMaterialParameterEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLuint, 
argTypes=(constants.GLenum,constants.GLenum,),
doc='glBindMaterialParameterEXT(GLenum(face), GLenum(value)) -> constants.GLuint',
argNames=('face','value',),
deprecated=_DEPRECATED,
)

glBindTexGenParameterEXT = platform.createExtensionFunction( 
'glBindTexGenParameterEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLuint, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,),
doc='glBindTexGenParameterEXT(GLenum(unit), GLenum(coord), GLenum(value)) -> constants.GLuint',
argNames=('unit','coord','value',),
deprecated=_DEPRECATED,
)

glBindTextureUnitParameterEXT = platform.createExtensionFunction( 
'glBindTextureUnitParameterEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLuint, 
argTypes=(constants.GLenum,constants.GLenum,),
doc='glBindTextureUnitParameterEXT(GLenum(unit), GLenum(value)) -> constants.GLuint',
argNames=('unit','value',),
deprecated=_DEPRECATED,
)

glBindParameterEXT = platform.createExtensionFunction( 
'glBindParameterEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLuint, 
argTypes=(constants.GLenum,),
doc='glBindParameterEXT(GLenum(value)) -> constants.GLuint',
argNames=('value',),
deprecated=_DEPRECATED,
)

glIsVariantEnabledEXT = platform.createExtensionFunction( 
'glIsVariantEnabledEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,constants.GLenum,),
doc='glIsVariantEnabledEXT(GLuint(id), GLenum(cap)) -> constants.GLboolean',
argNames=('id','cap',),
deprecated=_DEPRECATED,
)

glGetVariantBooleanvEXT = platform.createExtensionFunction( 
'glGetVariantBooleanvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLbooleanArray,),
doc='glGetVariantBooleanvEXT(GLuint(id), GLenum(value), GLbooleanArray(data)) -> None',
argNames=('id','value','data',),
deprecated=_DEPRECATED,
)

glGetVariantIntegervEXT = platform.createExtensionFunction( 
'glGetVariantIntegervEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetVariantIntegervEXT(GLuint(id), GLenum(value), GLintArray(data)) -> None',
argNames=('id','value','data',),
deprecated=_DEPRECATED,
)

glGetVariantFloatvEXT = platform.createExtensionFunction( 
'glGetVariantFloatvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLfloatArray,),
doc='glGetVariantFloatvEXT(GLuint(id), GLenum(value), GLfloatArray(data)) -> None',
argNames=('id','value','data',),
deprecated=_DEPRECATED,
)

glGetVariantPointervEXT = platform.createExtensionFunction( 
'glGetVariantPointervEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,ctypes.POINTER(ctypes.c_void_p),),
doc='glGetVariantPointervEXT(GLuint(id), GLenum(value), POINTER(ctypes.c_void_p)(data)) -> None',
argNames=('id','value','data',),
deprecated=_DEPRECATED,
)

glGetInvariantBooleanvEXT = platform.createExtensionFunction( 
'glGetInvariantBooleanvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLbooleanArray,),
doc='glGetInvariantBooleanvEXT(GLuint(id), GLenum(value), GLbooleanArray(data)) -> None',
argNames=('id','value','data',),
deprecated=_DEPRECATED,
)

glGetInvariantIntegervEXT = platform.createExtensionFunction( 
'glGetInvariantIntegervEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetInvariantIntegervEXT(GLuint(id), GLenum(value), GLintArray(data)) -> None',
argNames=('id','value','data',),
deprecated=_DEPRECATED,
)

glGetInvariantFloatvEXT = platform.createExtensionFunction( 
'glGetInvariantFloatvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLfloatArray,),
doc='glGetInvariantFloatvEXT(GLuint(id), GLenum(value), GLfloatArray(data)) -> None',
argNames=('id','value','data',),
deprecated=_DEPRECATED,
)

glGetLocalConstantBooleanvEXT = platform.createExtensionFunction( 
'glGetLocalConstantBooleanvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLbooleanArray,),
doc='glGetLocalConstantBooleanvEXT(GLuint(id), GLenum(value), GLbooleanArray(data)) -> None',
argNames=('id','value','data',),
deprecated=_DEPRECATED,
)

glGetLocalConstantIntegervEXT = platform.createExtensionFunction( 
'glGetLocalConstantIntegervEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetLocalConstantIntegervEXT(GLuint(id), GLenum(value), GLintArray(data)) -> None',
argNames=('id','value','data',),
deprecated=_DEPRECATED,
)

glGetLocalConstantFloatvEXT = platform.createExtensionFunction( 
'glGetLocalConstantFloatvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLenum,arrays.GLfloatArray,),
doc='glGetLocalConstantFloatvEXT(GLuint(id), GLenum(value), GLfloatArray(data)) -> None',
argNames=('id','value','data',),
deprecated=_DEPRECATED,
)


def glInitVertexShaderEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.gpu_program4

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_gpu_program4'
_DEPRECATED = False
GL_MIN_PROGRAM_TEXEL_OFFSET_NV = constant.Constant( 'GL_MIN_PROGRAM_TEXEL_OFFSET_NV', 0x8904 )
GL_MAX_PROGRAM_TEXEL_OFFSET_NV = constant.Constant( 'GL_MAX_PROGRAM_TEXEL_OFFSET_NV', 0x8905 )
GL_PROGRAM_ATTRIB_COMPONENTS_NV = constant.Constant( 'GL_PROGRAM_ATTRIB_COMPONENTS_NV', 0x8906 )
GL_PROGRAM_RESULT_COMPONENTS_NV = constant.Constant( 'GL_PROGRAM_RESULT_COMPONENTS_NV', 0x8907 )
GL_MAX_PROGRAM_ATTRIB_COMPONENTS_NV = constant.Constant( 'GL_MAX_PROGRAM_ATTRIB_COMPONENTS_NV', 0x8908 )
GL_MAX_PROGRAM_RESULT_COMPONENTS_NV = constant.Constant( 'GL_MAX_PROGRAM_RESULT_COMPONENTS_NV', 0x8909 )
GL_MAX_PROGRAM_GENERIC_ATTRIBS_NV = constant.Constant( 'GL_MAX_PROGRAM_GENERIC_ATTRIBS_NV', 0x8DA5 )
GL_MAX_PROGRAM_GENERIC_RESULTS_NV = constant.Constant( 'GL_MAX_PROGRAM_GENERIC_RESULTS_NV', 0x8DA6 )
glProgramLocalParameterI4iNV = platform.createExtensionFunction( 
'glProgramLocalParameterI4iNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,),
doc='glProgramLocalParameterI4iNV(GLenum(target), GLuint(index), GLint(x), GLint(y), GLint(z), GLint(w)) -> None',
argNames=('target','index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glProgramLocalParameterI4ivNV = platform.createExtensionFunction( 
'glProgramLocalParameterI4ivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLintArray,),
doc='glProgramLocalParameterI4ivNV(GLenum(target), GLuint(index), GLintArray(params)) -> None',
argNames=('target','index','params',),
deprecated=_DEPRECATED,
)

glProgramLocalParametersI4ivNV = platform.createExtensionFunction( 
'glProgramLocalParametersI4ivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLsizei,arrays.GLintArray,),
doc='glProgramLocalParametersI4ivNV(GLenum(target), GLuint(index), GLsizei(count), GLintArray(params)) -> None',
argNames=('target','index','count','params',),
deprecated=_DEPRECATED,
)

glProgramLocalParameterI4uiNV = platform.createExtensionFunction( 
'glProgramLocalParameterI4uiNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glProgramLocalParameterI4uiNV(GLenum(target), GLuint(index), GLuint(x), GLuint(y), GLuint(z), GLuint(w)) -> None',
argNames=('target','index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glProgramLocalParameterI4uivNV = platform.createExtensionFunction( 
'glProgramLocalParameterI4uivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLuintArray,),
doc='glProgramLocalParameterI4uivNV(GLenum(target), GLuint(index), GLuintArray(params)) -> None',
argNames=('target','index','params',),
deprecated=_DEPRECATED,
)

glProgramLocalParametersI4uivNV = platform.createExtensionFunction( 
'glProgramLocalParametersI4uivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLsizei,arrays.GLuintArray,),
doc='glProgramLocalParametersI4uivNV(GLenum(target), GLuint(index), GLsizei(count), GLuintArray(params)) -> None',
argNames=('target','index','count','params',),
deprecated=_DEPRECATED,
)

glProgramEnvParameterI4iNV = platform.createExtensionFunction( 
'glProgramEnvParameterI4iNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,),
doc='glProgramEnvParameterI4iNV(GLenum(target), GLuint(index), GLint(x), GLint(y), GLint(z), GLint(w)) -> None',
argNames=('target','index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glProgramEnvParameterI4ivNV = platform.createExtensionFunction( 
'glProgramEnvParameterI4ivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLintArray,),
doc='glProgramEnvParameterI4ivNV(GLenum(target), GLuint(index), GLintArray(params)) -> None',
argNames=('target','index','params',),
deprecated=_DEPRECATED,
)

glProgramEnvParametersI4ivNV = platform.createExtensionFunction( 
'glProgramEnvParametersI4ivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLsizei,arrays.GLintArray,),
doc='glProgramEnvParametersI4ivNV(GLenum(target), GLuint(index), GLsizei(count), GLintArray(params)) -> None',
argNames=('target','index','count','params',),
deprecated=_DEPRECATED,
)

glProgramEnvParameterI4uiNV = platform.createExtensionFunction( 
'glProgramEnvParameterI4uiNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,constants.GLuint,),
doc='glProgramEnvParameterI4uiNV(GLenum(target), GLuint(index), GLuint(x), GLuint(y), GLuint(z), GLuint(w)) -> None',
argNames=('target','index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glProgramEnvParameterI4uivNV = platform.createExtensionFunction( 
'glProgramEnvParameterI4uivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLuintArray,),
doc='glProgramEnvParameterI4uivNV(GLenum(target), GLuint(index), GLuintArray(params)) -> None',
argNames=('target','index','params',),
deprecated=_DEPRECATED,
)

glProgramEnvParametersI4uivNV = platform.createExtensionFunction( 
'glProgramEnvParametersI4uivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLsizei,arrays.GLuintArray,),
doc='glProgramEnvParametersI4uivNV(GLenum(target), GLuint(index), GLsizei(count), GLuintArray(params)) -> None',
argNames=('target','index','count','params',),
deprecated=_DEPRECATED,
)

glGetProgramLocalParameterIivNV = platform.createExtensionFunction( 
'glGetProgramLocalParameterIivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLintArray,),
doc='glGetProgramLocalParameterIivNV(GLenum(target), GLuint(index), GLintArray(params)) -> None',
argNames=('target','index','params',),
deprecated=_DEPRECATED,
)

glGetProgramLocalParameterIuivNV = platform.createExtensionFunction( 
'glGetProgramLocalParameterIuivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLuintArray,),
doc='glGetProgramLocalParameterIuivNV(GLenum(target), GLuint(index), GLuintArray(params)) -> None',
argNames=('target','index','params',),
deprecated=_DEPRECATED,
)

glGetProgramEnvParameterIivNV = platform.createExtensionFunction( 
'glGetProgramEnvParameterIivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLintArray,),
doc='glGetProgramEnvParameterIivNV(GLenum(target), GLuint(index), GLintArray(params)) -> None',
argNames=('target','index','params',),
deprecated=_DEPRECATED,
)

glGetProgramEnvParameterIuivNV = platform.createExtensionFunction( 
'glGetProgramEnvParameterIuivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,arrays.GLuintArray,),
doc='glGetProgramEnvParameterIuivNV(GLenum(target), GLuint(index), GLuintArray(params)) -> None',
argNames=('target','index','params',),
deprecated=_DEPRECATED,
)


def glInitGpuProgram4NV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.framebuffer_object

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_framebuffer_object'
_DEPRECATED = False
GL_INVALID_FRAMEBUFFER_OPERATION = constant.Constant( 'GL_INVALID_FRAMEBUFFER_OPERATION', 0x506 )
GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_COLOR_ENCODING', 0x8210 )
GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_COMPONENT_TYPE', 0x8211 )
GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_RED_SIZE', 0x8212 )
GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_GREEN_SIZE', 0x8213 )
GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_BLUE_SIZE', 0x8214 )
GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_ALPHA_SIZE', 0x8215 )
GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_DEPTH_SIZE', 0x8216 )
GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_STENCIL_SIZE', 0x8217 )
GL_FRAMEBUFFER_DEFAULT = constant.Constant( 'GL_FRAMEBUFFER_DEFAULT', 0x8218 )
GL_FRAMEBUFFER_UNDEFINED = constant.Constant( 'GL_FRAMEBUFFER_UNDEFINED', 0x8219 )
GL_DEPTH_STENCIL_ATTACHMENT = constant.Constant( 'GL_DEPTH_STENCIL_ATTACHMENT', 0x821A )
GL_MAX_RENDERBUFFER_SIZE = constant.Constant( 'GL_MAX_RENDERBUFFER_SIZE', 0x84E8 )
glget.addGLGetConstant( GL_MAX_RENDERBUFFER_SIZE, (1,) )
GL_DEPTH_STENCIL = constant.Constant( 'GL_DEPTH_STENCIL', 0x84F9 )
GL_UNSIGNED_INT_24_8 = constant.Constant( 'GL_UNSIGNED_INT_24_8', 0x84FA )
GL_DEPTH24_STENCIL8 = constant.Constant( 'GL_DEPTH24_STENCIL8', 0x88F0 )
GL_TEXTURE_STENCIL_SIZE = constant.Constant( 'GL_TEXTURE_STENCIL_SIZE', 0x88F1 )
GL_TEXTURE_RED_TYPE = constant.Constant( 'GL_TEXTURE_RED_TYPE', 0x8C10 )
GL_TEXTURE_GREEN_TYPE = constant.Constant( 'GL_TEXTURE_GREEN_TYPE', 0x8C11 )
GL_TEXTURE_BLUE_TYPE = constant.Constant( 'GL_TEXTURE_BLUE_TYPE', 0x8C12 )
GL_TEXTURE_ALPHA_TYPE = constant.Constant( 'GL_TEXTURE_ALPHA_TYPE', 0x8C13 )
GL_TEXTURE_DEPTH_TYPE = constant.Constant( 'GL_TEXTURE_DEPTH_TYPE', 0x8C16 )
GL_UNSIGNED_NORMALIZED = constant.Constant( 'GL_UNSIGNED_NORMALIZED', 0x8C17 )
GL_FRAMEBUFFER_BINDING = constant.Constant( 'GL_FRAMEBUFFER_BINDING', 0x8CA6 )
GL_RENDERBUFFER_BINDING = constant.Constant( 'GL_RENDERBUFFER_BINDING', 0x8CA7 )
glget.addGLGetConstant( GL_RENDERBUFFER_BINDING, (1,) )
GL_READ_FRAMEBUFFER = constant.Constant( 'GL_READ_FRAMEBUFFER', 0x8CA8 )
GL_DRAW_FRAMEBUFFER = constant.Constant( 'GL_DRAW_FRAMEBUFFER', 0x8CA9 )
GL_READ_FRAMEBUFFER_BINDING = constant.Constant( 'GL_READ_FRAMEBUFFER_BINDING', 0x8CAA )
GL_RENDERBUFFER_SAMPLES = constant.Constant( 'GL_RENDERBUFFER_SAMPLES', 0x8CAB )
GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_OBJECT_TYPE', 0x8CD0 )
GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_OBJECT_NAME', 0x8CD1 )
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LEVEL', 0x8CD2 )
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_CUBE_MAP_FACE', 0x8CD3 )
GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER = constant.Constant( 'GL_FRAMEBUFFER_ATTACHMENT_TEXTURE_LAYER', 0x8CD4 )
GL_FRAMEBUFFER_COMPLETE = constant.Constant( 'GL_FRAMEBUFFER_COMPLETE', 0x8CD5 )
GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT = constant.Constant( 'GL_FRAMEBUFFER_INCOMPLETE_ATTACHMENT', 0x8CD6 )
GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT = constant.Constant( 'GL_FRAMEBUFFER_INCOMPLETE_MISSING_ATTACHMENT', 0x8CD7 )
GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER = constant.Constant( 'GL_FRAMEBUFFER_INCOMPLETE_DRAW_BUFFER', 0x8CDB )
GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER = constant.Constant( 'GL_FRAMEBUFFER_INCOMPLETE_READ_BUFFER', 0x8CDC )
GL_FRAMEBUFFER_UNSUPPORTED = constant.Constant( 'GL_FRAMEBUFFER_UNSUPPORTED', 0x8CDD )
GL_MAX_COLOR_ATTACHMENTS = constant.Constant( 'GL_MAX_COLOR_ATTACHMENTS', 0x8CDF )
glget.addGLGetConstant( GL_MAX_COLOR_ATTACHMENTS, (1,) )
GL_COLOR_ATTACHMENT0 = constant.Constant( 'GL_COLOR_ATTACHMENT0', 0x8CE0 )
GL_COLOR_ATTACHMENT1 = constant.Constant( 'GL_COLOR_ATTACHMENT1', 0x8CE1 )
GL_COLOR_ATTACHMENT2 = constant.Constant( 'GL_COLOR_ATTACHMENT2', 0x8CE2 )
GL_COLOR_ATTACHMENT3 = constant.Constant( 'GL_COLOR_ATTACHMENT3', 0x8CE3 )
GL_COLOR_ATTACHMENT4 = constant.Constant( 'GL_COLOR_ATTACHMENT4', 0x8CE4 )
GL_COLOR_ATTACHMENT5 = constant.Constant( 'GL_COLOR_ATTACHMENT5', 0x8CE5 )
GL_COLOR_ATTACHMENT6 = constant.Constant( 'GL_COLOR_ATTACHMENT6', 0x8CE6 )
GL_COLOR_ATTACHMENT7 = constant.Constant( 'GL_COLOR_ATTACHMENT7', 0x8CE7 )
GL_COLOR_ATTACHMENT8 = constant.Constant( 'GL_COLOR_ATTACHMENT8', 0x8CE8 )
GL_COLOR_ATTACHMENT9 = constant.Constant( 'GL_COLOR_ATTACHMENT9', 0x8CE9 )
GL_COLOR_ATTACHMENT10 = constant.Constant( 'GL_COLOR_ATTACHMENT10', 0x8CEA )
GL_COLOR_ATTACHMENT11 = constant.Constant( 'GL_COLOR_ATTACHMENT11', 0x8CEB )
GL_COLOR_ATTACHMENT12 = constant.Constant( 'GL_COLOR_ATTACHMENT12', 0x8CEC )
GL_COLOR_ATTACHMENT13 = constant.Constant( 'GL_COLOR_ATTACHMENT13', 0x8CED )
GL_COLOR_ATTACHMENT14 = constant.Constant( 'GL_COLOR_ATTACHMENT14', 0x8CEE )
GL_COLOR_ATTACHMENT15 = constant.Constant( 'GL_COLOR_ATTACHMENT15', 0x8CEF )
GL_DEPTH_ATTACHMENT = constant.Constant( 'GL_DEPTH_ATTACHMENT', 0x8D00 )
GL_STENCIL_ATTACHMENT = constant.Constant( 'GL_STENCIL_ATTACHMENT', 0x8D20 )
GL_FRAMEBUFFER = constant.Constant( 'GL_FRAMEBUFFER', 0x8D40 )
GL_RENDERBUFFER = constant.Constant( 'GL_RENDERBUFFER', 0x8D41 )
GL_RENDERBUFFER_WIDTH = constant.Constant( 'GL_RENDERBUFFER_WIDTH', 0x8D42 )
GL_RENDERBUFFER_HEIGHT = constant.Constant( 'GL_RENDERBUFFER_HEIGHT', 0x8D43 )
GL_RENDERBUFFER_INTERNAL_FORMAT = constant.Constant( 'GL_RENDERBUFFER_INTERNAL_FORMAT', 0x8D44 )
GL_STENCIL_INDEX1 = constant.Constant( 'GL_STENCIL_INDEX1', 0x8D46 )
GL_STENCIL_INDEX4 = constant.Constant( 'GL_STENCIL_INDEX4', 0x8D47 )
GL_STENCIL_INDEX8 = constant.Constant( 'GL_STENCIL_INDEX8', 0x8D48 )
GL_STENCIL_INDEX16 = constant.Constant( 'GL_STENCIL_INDEX16', 0x8D49 )
GL_RENDERBUFFER_RED_SIZE = constant.Constant( 'GL_RENDERBUFFER_RED_SIZE', 0x8D50 )
GL_RENDERBUFFER_GREEN_SIZE = constant.Constant( 'GL_RENDERBUFFER_GREEN_SIZE', 0x8D51 )
GL_RENDERBUFFER_BLUE_SIZE = constant.Constant( 'GL_RENDERBUFFER_BLUE_SIZE', 0x8D52 )
GL_RENDERBUFFER_ALPHA_SIZE = constant.Constant( 'GL_RENDERBUFFER_ALPHA_SIZE', 0x8D53 )
GL_RENDERBUFFER_DEPTH_SIZE = constant.Constant( 'GL_RENDERBUFFER_DEPTH_SIZE', 0x8D54 )
GL_RENDERBUFFER_STENCIL_SIZE = constant.Constant( 'GL_RENDERBUFFER_STENCIL_SIZE', 0x8D55 )
GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE = constant.Constant( 'GL_FRAMEBUFFER_INCOMPLETE_MULTISAMPLE', 0x8D56 )
GL_MAX_SAMPLES = constant.Constant( 'GL_MAX_SAMPLES', 0x8D57 )
glget.addGLGetConstant( GL_MAX_SAMPLES, (1,) )
glIsRenderbuffer = platform.createExtensionFunction( 
'glIsRenderbuffer',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glIsRenderbuffer(GLuint(renderbuffer)) -> constants.GLboolean',
argNames=('renderbuffer',),
deprecated=_DEPRECATED,
)

glBindRenderbuffer = platform.createExtensionFunction( 
'glBindRenderbuffer',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glBindRenderbuffer(GLenum(target), GLuint(renderbuffer)) -> None',
argNames=('target','renderbuffer',),
deprecated=_DEPRECATED,
)

glDeleteRenderbuffers = platform.createExtensionFunction( 
'glDeleteRenderbuffers',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glDeleteRenderbuffers(GLsizei(n), GLuintArray(renderbuffers)) -> None',
argNames=('n','renderbuffers',),
deprecated=_DEPRECATED,
)

glGenRenderbuffers = platform.createExtensionFunction( 
'glGenRenderbuffers',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glGenRenderbuffers(GLsizei(n), GLuintArray(renderbuffers)) -> None',
argNames=('n','renderbuffers',),
deprecated=_DEPRECATED,
)

glRenderbufferStorage = platform.createExtensionFunction( 
'glRenderbufferStorage',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLsizei,constants.GLsizei,),
doc='glRenderbufferStorage(GLenum(target), GLenum(internalformat), GLsizei(width), GLsizei(height)) -> None',
argNames=('target','internalformat','width','height',),
deprecated=_DEPRECATED,
)

glGetRenderbufferParameteriv = platform.createExtensionFunction( 
'glGetRenderbufferParameteriv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetRenderbufferParameteriv(GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glIsFramebuffer = platform.createExtensionFunction( 
'glIsFramebuffer',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLuint,),
doc='glIsFramebuffer(GLuint(framebuffer)) -> constants.GLboolean',
argNames=('framebuffer',),
deprecated=_DEPRECATED,
)

glBindFramebuffer = platform.createExtensionFunction( 
'glBindFramebuffer',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,),
doc='glBindFramebuffer(GLenum(target), GLuint(framebuffer)) -> None',
argNames=('target','framebuffer',),
deprecated=_DEPRECATED,
)

glDeleteFramebuffers = platform.createExtensionFunction( 
'glDeleteFramebuffers',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glDeleteFramebuffers(GLsizei(n), GLuintArray(framebuffers)) -> None',
argNames=('n','framebuffers',),
deprecated=_DEPRECATED,
)

glGenFramebuffers = platform.createExtensionFunction( 
'glGenFramebuffers',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,arrays.GLuintArray,),
doc='glGenFramebuffers(GLsizei(n), GLuintArray(framebuffers)) -> None',
argNames=('n','framebuffers',),
deprecated=_DEPRECATED,
)

glCheckFramebufferStatus = platform.createExtensionFunction( 
'glCheckFramebufferStatus',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLenum, 
argTypes=(constants.GLenum,),
doc='glCheckFramebufferStatus(GLenum(target)) -> constants.GLenum',
argNames=('target',),
deprecated=_DEPRECATED,
)

glFramebufferTexture1D = platform.createExtensionFunction( 
'glFramebufferTexture1D',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLuint,constants.GLint,),
doc='glFramebufferTexture1D(GLenum(target), GLenum(attachment), GLenum(textarget), GLuint(texture), GLint(level)) -> None',
argNames=('target','attachment','textarget','texture','level',),
deprecated=_DEPRECATED,
)

glFramebufferTexture2D = platform.createExtensionFunction( 
'glFramebufferTexture2D',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLuint,constants.GLint,),
doc='glFramebufferTexture2D(GLenum(target), GLenum(attachment), GLenum(textarget), GLuint(texture), GLint(level)) -> None',
argNames=('target','attachment','textarget','texture','level',),
deprecated=_DEPRECATED,
)

glFramebufferTexture3D = platform.createExtensionFunction( 
'glFramebufferTexture3D',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLuint,constants.GLint,constants.GLint,),
doc='glFramebufferTexture3D(GLenum(target), GLenum(attachment), GLenum(textarget), GLuint(texture), GLint(level), GLint(zoffset)) -> None',
argNames=('target','attachment','textarget','texture','level','zoffset',),
deprecated=_DEPRECATED,
)

glFramebufferRenderbuffer = platform.createExtensionFunction( 
'glFramebufferRenderbuffer',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,constants.GLuint,),
doc='glFramebufferRenderbuffer(GLenum(target), GLenum(attachment), GLenum(renderbuffertarget), GLuint(renderbuffer)) -> None',
argNames=('target','attachment','renderbuffertarget','renderbuffer',),
deprecated=_DEPRECATED,
)

glGetFramebufferAttachmentParameteriv = platform.createExtensionFunction( 
'glGetFramebufferAttachmentParameteriv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetFramebufferAttachmentParameteriv(GLenum(target), GLenum(attachment), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','attachment','pname','params',),
deprecated=_DEPRECATED,
)

glGenerateMipmap = platform.createExtensionFunction( 
'glGenerateMipmap',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glGenerateMipmap(GLenum(target)) -> None',
argNames=('target',),
deprecated=_DEPRECATED,
)

glBlitFramebuffer = platform.createExtensionFunction( 
'glBlitFramebuffer',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLbitfield,constants.GLenum,),
doc='glBlitFramebuffer(GLint(srcX0), GLint(srcY0), GLint(srcX1), GLint(srcY1), GLint(dstX0), GLint(dstY0), GLint(dstX1), GLint(dstY1), GLbitfield(mask), GLenum(filter)) -> None',
argNames=('srcX0','srcY0','srcX1','srcY1','dstX0','dstY0','dstX1','dstY1','mask','filter',),
deprecated=_DEPRECATED,
)

glRenderbufferStorageMultisample = platform.createExtensionFunction( 
'glRenderbufferStorageMultisample',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,constants.GLenum,constants.GLsizei,constants.GLsizei,),
doc='glRenderbufferStorageMultisample(GLenum(target), GLsizei(samples), GLenum(internalformat), GLsizei(width), GLsizei(height)) -> None',
argNames=('target','samples','internalformat','width','height',),
deprecated=_DEPRECATED,
)

glFramebufferTextureLayer = platform.createExtensionFunction( 
'glFramebufferTextureLayer',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLuint,constants.GLint,constants.GLint,),
doc='glFramebufferTextureLayer(GLenum(target), GLenum(attachment), GLuint(texture), GLint(level), GLint(layer)) -> None',
argNames=('target','attachment','texture','level','layer',),
deprecated=_DEPRECATED,
)
# import legacy entry points to allow checking for bool(entryPoint)
from OpenGL.raw.GL.ARB.framebuffer_object_DEPRECATED import *

def glInitFramebufferObjectARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ATI.meminfo

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ATI_meminfo'
_DEPRECATED = False
GL_VBO_FREE_MEMORY_ATI = constant.Constant( 'GL_VBO_FREE_MEMORY_ATI', 0x87FB )
glget.addGLGetConstant( GL_VBO_FREE_MEMORY_ATI, (1,) )
GL_TEXTURE_FREE_MEMORY_ATI = constant.Constant( 'GL_TEXTURE_FREE_MEMORY_ATI', 0x87FC )
glget.addGLGetConstant( GL_TEXTURE_FREE_MEMORY_ATI, (1,) )
GL_RENDERBUFFER_FREE_MEMORY_ATI = constant.Constant( 'GL_RENDERBUFFER_FREE_MEMORY_ATI', 0x87FD )
glget.addGLGetConstant( GL_RENDERBUFFER_FREE_MEMORY_ATI, (1,) )


def glInitMeminfoATI():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIS.pixel_texture

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIS_pixel_texture'
_DEPRECATED = False
GL_PIXEL_TEXTURE_SGIS = constant.Constant( 'GL_PIXEL_TEXTURE_SGIS', 0x8353 )
GL_PIXEL_FRAGMENT_RGB_SOURCE_SGIS = constant.Constant( 'GL_PIXEL_FRAGMENT_RGB_SOURCE_SGIS', 0x8354 )
GL_PIXEL_FRAGMENT_ALPHA_SOURCE_SGIS = constant.Constant( 'GL_PIXEL_FRAGMENT_ALPHA_SOURCE_SGIS', 0x8355 )
GL_PIXEL_GROUP_COLOR_SGIS = constant.Constant( 'GL_PIXEL_GROUP_COLOR_SGIS', 0x8356 )
glPixelTexGenParameteriSGIS = platform.createExtensionFunction( 
'glPixelTexGenParameteriSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,),
doc='glPixelTexGenParameteriSGIS(GLenum(pname), GLint(param)) -> None',
argNames=('pname','param',),
deprecated=_DEPRECATED,
)

glPixelTexGenParameterivSGIS = platform.createExtensionFunction( 
'glPixelTexGenParameterivSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glPixelTexGenParameterivSGIS(GLenum(pname), GLintArray(params)) -> None',
argNames=('pname','params',),
deprecated=_DEPRECATED,
)

glPixelTexGenParameterfSGIS = platform.createExtensionFunction( 
'glPixelTexGenParameterfSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLfloat,),
doc='glPixelTexGenParameterfSGIS(GLenum(pname), GLfloat(param)) -> None',
argNames=('pname','param',),
deprecated=_DEPRECATED,
)

glPixelTexGenParameterfvSGIS = platform.createExtensionFunction( 
'glPixelTexGenParameterfvSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glPixelTexGenParameterfvSGIS(GLenum(pname), GLfloatArray(params)) -> None',
argNames=('pname','params',),
deprecated=_DEPRECATED,
)

glGetPixelTexGenParameterivSGIS = platform.createExtensionFunction( 
'glGetPixelTexGenParameterivSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLintArray,),
doc='glGetPixelTexGenParameterivSGIS(GLenum(pname), GLintArray(params)) -> None',
argNames=('pname','params',),
deprecated=_DEPRECATED,
)

glGetPixelTexGenParameterfvSGIS = platform.createExtensionFunction( 
'glGetPixelTexGenParameterfvSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLfloatArray,),
doc='glGetPixelTexGenParameterfvSGIS(GLenum(pname), GLfloatArray(params)) -> None',
argNames=('pname','params',),
deprecated=_DEPRECATED,
)


def glInitPixelTextureSGIS():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.half_float

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_half_float'
_DEPRECATED = False
GL_HALF_FLOAT_NV = constant.Constant( 'GL_HALF_FLOAT_NV', 0x140B )
glVertex2hNV = platform.createExtensionFunction( 
'glVertex2hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLhalfNV,constants.GLhalfNV,),
doc='glVertex2hNV(GLhalfNV(x), GLhalfNV(y)) -> None',
argNames=('x','y',),
deprecated=_DEPRECATED,
)

glVertex2hvNV = platform.createExtensionFunction( 
'glVertex2hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLushortArray,),
doc='glVertex2hvNV(GLushortArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glVertex3hNV = platform.createExtensionFunction( 
'glVertex3hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLhalfNV,constants.GLhalfNV,constants.GLhalfNV,),
doc='glVertex3hNV(GLhalfNV(x), GLhalfNV(y), GLhalfNV(z)) -> None',
argNames=('x','y','z',),
deprecated=_DEPRECATED,
)

glVertex3hvNV = platform.createExtensionFunction( 
'glVertex3hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLushortArray,),
doc='glVertex3hvNV(GLushortArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glVertex4hNV = platform.createExtensionFunction( 
'glVertex4hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLhalfNV,constants.GLhalfNV,constants.GLhalfNV,constants.GLhalfNV,),
doc='glVertex4hNV(GLhalfNV(x), GLhalfNV(y), GLhalfNV(z), GLhalfNV(w)) -> None',
argNames=('x','y','z','w',),
deprecated=_DEPRECATED,
)

glVertex4hvNV = platform.createExtensionFunction( 
'glVertex4hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLushortArray,),
doc='glVertex4hvNV(GLushortArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glNormal3hNV = platform.createExtensionFunction( 
'glNormal3hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLhalfNV,constants.GLhalfNV,constants.GLhalfNV,),
doc='glNormal3hNV(GLhalfNV(nx), GLhalfNV(ny), GLhalfNV(nz)) -> None',
argNames=('nx','ny','nz',),
deprecated=_DEPRECATED,
)

glNormal3hvNV = platform.createExtensionFunction( 
'glNormal3hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLushortArray,),
doc='glNormal3hvNV(GLushortArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glColor3hNV = platform.createExtensionFunction( 
'glColor3hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLhalfNV,constants.GLhalfNV,constants.GLhalfNV,),
doc='glColor3hNV(GLhalfNV(red), GLhalfNV(green), GLhalfNV(blue)) -> None',
argNames=('red','green','blue',),
deprecated=_DEPRECATED,
)

glColor3hvNV = platform.createExtensionFunction( 
'glColor3hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLushortArray,),
doc='glColor3hvNV(GLushortArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glColor4hNV = platform.createExtensionFunction( 
'glColor4hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLhalfNV,constants.GLhalfNV,constants.GLhalfNV,constants.GLhalfNV,),
doc='glColor4hNV(GLhalfNV(red), GLhalfNV(green), GLhalfNV(blue), GLhalfNV(alpha)) -> None',
argNames=('red','green','blue','alpha',),
deprecated=_DEPRECATED,
)

glColor4hvNV = platform.createExtensionFunction( 
'glColor4hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLushortArray,),
doc='glColor4hvNV(GLushortArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glTexCoord1hNV = platform.createExtensionFunction( 
'glTexCoord1hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLhalfNV,),
doc='glTexCoord1hNV(GLhalfNV(s)) -> None',
argNames=('s',),
deprecated=_DEPRECATED,
)

glTexCoord1hvNV = platform.createExtensionFunction( 
'glTexCoord1hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLushortArray,),
doc='glTexCoord1hvNV(GLushortArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glTexCoord2hNV = platform.createExtensionFunction( 
'glTexCoord2hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLhalfNV,constants.GLhalfNV,),
doc='glTexCoord2hNV(GLhalfNV(s), GLhalfNV(t)) -> None',
argNames=('s','t',),
deprecated=_DEPRECATED,
)

glTexCoord2hvNV = platform.createExtensionFunction( 
'glTexCoord2hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLushortArray,),
doc='glTexCoord2hvNV(GLushortArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glTexCoord3hNV = platform.createExtensionFunction( 
'glTexCoord3hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLhalfNV,constants.GLhalfNV,constants.GLhalfNV,),
doc='glTexCoord3hNV(GLhalfNV(s), GLhalfNV(t), GLhalfNV(r)) -> None',
argNames=('s','t','r',),
deprecated=_DEPRECATED,
)

glTexCoord3hvNV = platform.createExtensionFunction( 
'glTexCoord3hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLushortArray,),
doc='glTexCoord3hvNV(GLushortArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glTexCoord4hNV = platform.createExtensionFunction( 
'glTexCoord4hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLhalfNV,constants.GLhalfNV,constants.GLhalfNV,constants.GLhalfNV,),
doc='glTexCoord4hNV(GLhalfNV(s), GLhalfNV(t), GLhalfNV(r), GLhalfNV(q)) -> None',
argNames=('s','t','r','q',),
deprecated=_DEPRECATED,
)

glTexCoord4hvNV = platform.createExtensionFunction( 
'glTexCoord4hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLushortArray,),
doc='glTexCoord4hvNV(GLushortArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord1hNV = platform.createExtensionFunction( 
'glMultiTexCoord1hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLhalfNV,),
doc='glMultiTexCoord1hNV(GLenum(target), GLhalfNV(s)) -> None',
argNames=('target','s',),
deprecated=_DEPRECATED,
)

glMultiTexCoord1hvNV = platform.createExtensionFunction( 
'glMultiTexCoord1hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLushortArray,),
doc='glMultiTexCoord1hvNV(GLenum(target), GLushortArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord2hNV = platform.createExtensionFunction( 
'glMultiTexCoord2hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLhalfNV,constants.GLhalfNV,),
doc='glMultiTexCoord2hNV(GLenum(target), GLhalfNV(s), GLhalfNV(t)) -> None',
argNames=('target','s','t',),
deprecated=_DEPRECATED,
)

glMultiTexCoord2hvNV = platform.createExtensionFunction( 
'glMultiTexCoord2hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLushortArray,),
doc='glMultiTexCoord2hvNV(GLenum(target), GLushortArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord3hNV = platform.createExtensionFunction( 
'glMultiTexCoord3hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLhalfNV,constants.GLhalfNV,constants.GLhalfNV,),
doc='glMultiTexCoord3hNV(GLenum(target), GLhalfNV(s), GLhalfNV(t), GLhalfNV(r)) -> None',
argNames=('target','s','t','r',),
deprecated=_DEPRECATED,
)

glMultiTexCoord3hvNV = platform.createExtensionFunction( 
'glMultiTexCoord3hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLushortArray,),
doc='glMultiTexCoord3hvNV(GLenum(target), GLushortArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glMultiTexCoord4hNV = platform.createExtensionFunction( 
'glMultiTexCoord4hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLhalfNV,constants.GLhalfNV,constants.GLhalfNV,constants.GLhalfNV,),
doc='glMultiTexCoord4hNV(GLenum(target), GLhalfNV(s), GLhalfNV(t), GLhalfNV(r), GLhalfNV(q)) -> None',
argNames=('target','s','t','r','q',),
deprecated=_DEPRECATED,
)

glMultiTexCoord4hvNV = platform.createExtensionFunction( 
'glMultiTexCoord4hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLushortArray,),
doc='glMultiTexCoord4hvNV(GLenum(target), GLushortArray(v)) -> None',
argNames=('target','v',),
deprecated=_DEPRECATED,
)

glFogCoordhNV = platform.createExtensionFunction( 
'glFogCoordhNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLhalfNV,),
doc='glFogCoordhNV(GLhalfNV(fog)) -> None',
argNames=('fog',),
deprecated=_DEPRECATED,
)

glFogCoordhvNV = platform.createExtensionFunction( 
'glFogCoordhvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLushortArray,),
doc='glFogCoordhvNV(GLushortArray(fog)) -> None',
argNames=('fog',),
deprecated=_DEPRECATED,
)

glSecondaryColor3hNV = platform.createExtensionFunction( 
'glSecondaryColor3hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLhalfNV,constants.GLhalfNV,constants.GLhalfNV,),
doc='glSecondaryColor3hNV(GLhalfNV(red), GLhalfNV(green), GLhalfNV(blue)) -> None',
argNames=('red','green','blue',),
deprecated=_DEPRECATED,
)

glSecondaryColor3hvNV = platform.createExtensionFunction( 
'glSecondaryColor3hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLushortArray,),
doc='glSecondaryColor3hvNV(GLushortArray(v)) -> None',
argNames=('v',),
deprecated=_DEPRECATED,
)

glVertexWeighthNV = platform.createExtensionFunction( 
'glVertexWeighthNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLhalfNV,),
doc='glVertexWeighthNV(GLhalfNV(weight)) -> None',
argNames=('weight',),
deprecated=_DEPRECATED,
)

glVertexWeighthvNV = platform.createExtensionFunction( 
'glVertexWeighthvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLushortArray,),
doc='glVertexWeighthvNV(GLushortArray(weight)) -> None',
argNames=('weight',),
deprecated=_DEPRECATED,
)

glVertexAttrib1hNV = platform.createExtensionFunction( 
'glVertexAttrib1hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLhalfNV,),
doc='glVertexAttrib1hNV(GLuint(index), GLhalfNV(x)) -> None',
argNames=('index','x',),
deprecated=_DEPRECATED,
)

glVertexAttrib1hvNV = platform.createExtensionFunction( 
'glVertexAttrib1hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLushortArray,),
doc='glVertexAttrib1hvNV(GLuint(index), GLushortArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib2hNV = platform.createExtensionFunction( 
'glVertexAttrib2hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLhalfNV,constants.GLhalfNV,),
doc='glVertexAttrib2hNV(GLuint(index), GLhalfNV(x), GLhalfNV(y)) -> None',
argNames=('index','x','y',),
deprecated=_DEPRECATED,
)

glVertexAttrib2hvNV = platform.createExtensionFunction( 
'glVertexAttrib2hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLushortArray,),
doc='glVertexAttrib2hvNV(GLuint(index), GLushortArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib3hNV = platform.createExtensionFunction( 
'glVertexAttrib3hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLhalfNV,constants.GLhalfNV,constants.GLhalfNV,),
doc='glVertexAttrib3hNV(GLuint(index), GLhalfNV(x), GLhalfNV(y), GLhalfNV(z)) -> None',
argNames=('index','x','y','z',),
deprecated=_DEPRECATED,
)

glVertexAttrib3hvNV = platform.createExtensionFunction( 
'glVertexAttrib3hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLushortArray,),
doc='glVertexAttrib3hvNV(GLuint(index), GLushortArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttrib4hNV = platform.createExtensionFunction( 
'glVertexAttrib4hNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLhalfNV,constants.GLhalfNV,constants.GLhalfNV,constants.GLhalfNV,),
doc='glVertexAttrib4hNV(GLuint(index), GLhalfNV(x), GLhalfNV(y), GLhalfNV(z), GLhalfNV(w)) -> None',
argNames=('index','x','y','z','w',),
deprecated=_DEPRECATED,
)

glVertexAttrib4hvNV = platform.createExtensionFunction( 
'glVertexAttrib4hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,arrays.GLushortArray,),
doc='glVertexAttrib4hvNV(GLuint(index), GLushortArray(v)) -> None',
argNames=('index','v',),
deprecated=_DEPRECATED,
)

glVertexAttribs1hvNV = platform.createExtensionFunction( 
'glVertexAttribs1hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLushortArray,),
doc='glVertexAttribs1hvNV(GLuint(index), GLsizei(n), GLushortArray(v)) -> None',
argNames=('index','n','v',),
deprecated=_DEPRECATED,
)

glVertexAttribs2hvNV = platform.createExtensionFunction( 
'glVertexAttribs2hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLushortArray,),
doc='glVertexAttribs2hvNV(GLuint(index), GLsizei(n), GLushortArray(v)) -> None',
argNames=('index','n','v',),
deprecated=_DEPRECATED,
)

glVertexAttribs3hvNV = platform.createExtensionFunction( 
'glVertexAttribs3hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLushortArray,),
doc='glVertexAttribs3hvNV(GLuint(index), GLsizei(n), GLushortArray(v)) -> None',
argNames=('index','n','v',),
deprecated=_DEPRECATED,
)

glVertexAttribs4hvNV = platform.createExtensionFunction( 
'glVertexAttribs4hvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLuint,constants.GLsizei,arrays.GLushortArray,),
doc='glVertexAttribs4hvNV(GLuint(index), GLsizei(n), GLushortArray(v)) -> None',
argNames=('index','n','v',),
deprecated=_DEPRECATED,
)


def glInitHalfFloatNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.texture_barrier

This module customises the behaviour of the 
OpenGL.raw.GL.NV.texture_barrier to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension relaxes the restrictions on rendering to a currently
	bound texture and provides a mechanism to avoid read-after-write
	hazards.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/texture_barrier.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.NV.texture_barrier import *
### END AUTOGENERATED SECTION


'''OpenGL extension ARB.texture_query_lod

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_texture_query_lod'
_DEPRECATED = False



def glInitTextureQueryLodARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.sync

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_sync'
_DEPRECATED = False
GL_MAX_SERVER_WAIT_TIMEOUT = constant.Constant( 'GL_MAX_SERVER_WAIT_TIMEOUT', 0x9111 )
GL_OBJECT_TYPE = constant.Constant( 'GL_OBJECT_TYPE', 0x9112 )
GL_SYNC_CONDITION = constant.Constant( 'GL_SYNC_CONDITION', 0x9113 )
GL_SYNC_STATUS = constant.Constant( 'GL_SYNC_STATUS', 0x9114 )
GL_SYNC_FLAGS = constant.Constant( 'GL_SYNC_FLAGS', 0x9115 )
GL_SYNC_FENCE = constant.Constant( 'GL_SYNC_FENCE', 0x9116 )
GL_SYNC_GPU_COMMANDS_COMPLETE = constant.Constant( 'GL_SYNC_GPU_COMMANDS_COMPLETE', 0x9117 )
GL_UNSIGNALED = constant.Constant( 'GL_UNSIGNALED', 0x9118 )
GL_SIGNALED = constant.Constant( 'GL_SIGNALED', 0x9119 )
GL_ALREADY_SIGNALED = constant.Constant( 'GL_ALREADY_SIGNALED', 0x911A )
GL_TIMEOUT_EXPIRED = constant.Constant( 'GL_TIMEOUT_EXPIRED', 0x911B )
GL_CONDITION_SATISFIED = constant.Constant( 'GL_CONDITION_SATISFIED', 0x911C )
GL_WAIT_FAILED = constant.Constant( 'GL_WAIT_FAILED', 0x911D )
GL_SYNC_FLUSH_COMMANDS_BIT = constant.Constant( 'GL_SYNC_FLUSH_COMMANDS_BIT', 0x1 )
GL_TIMEOUT_IGNORED = constant.Constant( 'GL_TIMEOUT_IGNORED', 0xFFFFFFFFFFFFFFFF )
glFenceSync = platform.createExtensionFunction( 
'glFenceSync',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLsync, 
argTypes=(constants.GLenum,constants.GLbitfield,),
doc='glFenceSync(GLenum(condition), GLbitfield(flags)) -> constants.GLsync',
argNames=('condition','flags',),
deprecated=_DEPRECATED,
)

glIsSync = platform.createExtensionFunction( 
'glIsSync',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLboolean, 
argTypes=(constants.GLsync,),
doc='glIsSync(GLsync(sync)) -> constants.GLboolean',
argNames=('sync',),
deprecated=_DEPRECATED,
)

glDeleteSync = platform.createExtensionFunction( 
'glDeleteSync',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsync,),
doc='glDeleteSync(GLsync(sync)) -> None',
argNames=('sync',),
deprecated=_DEPRECATED,
)

glClientWaitSync = platform.createExtensionFunction( 
'glClientWaitSync',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=constants.GLenum, 
argTypes=(constants.GLsync,constants.GLbitfield,constants.GLuint64,),
doc='glClientWaitSync(GLsync(sync), GLbitfield(flags), GLuint64(timeout)) -> constants.GLenum',
argNames=('sync','flags','timeout',),
deprecated=_DEPRECATED,
)

glWaitSync = platform.createExtensionFunction( 
'glWaitSync',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsync,constants.GLbitfield,constants.GLuint64,),
doc='glWaitSync(GLsync(sync), GLbitfield(flags), GLuint64(timeout)) -> None',
argNames=('sync','flags','timeout',),
deprecated=_DEPRECATED,
)

glGetInteger64v = platform.createExtensionFunction( 
'glGetInteger64v',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLint64Array,),
doc='glGetInteger64v(GLenum(pname), GLint64Array(params)) -> None',
argNames=('pname','params',),
deprecated=_DEPRECATED,
)

glGetSynciv = platform.createExtensionFunction( 
'glGetSynciv',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsync,constants.GLenum,constants.GLsizei,arrays.GLsizeiArray,arrays.GLintArray,),
doc='glGetSynciv(GLsync(sync), GLenum(pname), GLsizei(bufSize), GLsizeiArray(length), GLintArray(values)) -> None',
argNames=('sync','pname','bufSize','length','values',),
deprecated=_DEPRECATED,
)


def glInitSyncARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.cmyka

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_cmyka'
_DEPRECATED = False
GL_CMYK_EXT = constant.Constant( 'GL_CMYK_EXT', 0x800C )
GL_CMYKA_EXT = constant.Constant( 'GL_CMYKA_EXT', 0x800D )
GL_PACK_CMYK_HINT_EXT = constant.Constant( 'GL_PACK_CMYK_HINT_EXT', 0x800E )
glget.addGLGetConstant( GL_PACK_CMYK_HINT_EXT, (1,) )
GL_UNPACK_CMYK_HINT_EXT = constant.Constant( 'GL_UNPACK_CMYK_HINT_EXT', 0x800F )
glget.addGLGetConstant( GL_UNPACK_CMYK_HINT_EXT, (1,) )


def glInitCmykaEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.separate_specular_color

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_separate_specular_color'
_DEPRECATED = False
GL_LIGHT_MODEL_COLOR_CONTROL_EXT = constant.Constant( 'GL_LIGHT_MODEL_COLOR_CONTROL_EXT', 0x81F8 )
glget.addGLGetConstant( GL_LIGHT_MODEL_COLOR_CONTROL_EXT, (1,) )
GL_SINGLE_COLOR_EXT = constant.Constant( 'GL_SINGLE_COLOR_EXT', 0x81F9 )
GL_SEPARATE_SPECULAR_COLOR_EXT = constant.Constant( 'GL_SEPARATE_SPECULAR_COLOR_EXT', 0x81FA )


def glInitSeparateSpecularColorEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIS.texture_filter4

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIS_texture_filter4'
_DEPRECATED = False
GL_FILTER4_SGIS = constant.Constant( 'GL_FILTER4_SGIS', 0x8146 )
GL_TEXTURE_FILTER4_SIZE_SGIS = constant.Constant( 'GL_TEXTURE_FILTER4_SIZE_SGIS', 0x8147 )
glGetTexFilterFuncSGIS = platform.createExtensionFunction( 
'glGetTexFilterFuncSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetTexFilterFuncSGIS(GLenum(target), GLenum(filter), GLfloatArray(weights)) -> None',
argNames=('target','filter','weights',),
deprecated=_DEPRECATED,
)

glTexFilterFuncSGIS = platform.createExtensionFunction( 
'glTexFilterFuncSGIS',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,constants.GLsizei,arrays.GLfloatArray,),
doc='glTexFilterFuncSGIS(GLenum(target), GLenum(filter), GLsizei(n), GLfloatArray(weights)) -> None',
argNames=('target','filter','n','weights',),
deprecated=_DEPRECATED,
)


def glInitTextureFilter4SGIS():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension OML.interlace

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_OML_interlace'
_DEPRECATED = False
GL_INTERLACE_OML = constant.Constant( 'GL_INTERLACE_OML', 0x8980 )
glget.addGLGetConstant( GL_INTERLACE_OML, (1,) )
GL_INTERLACE_READ_OML = constant.Constant( 'GL_INTERLACE_READ_OML', 0x8981 )
glget.addGLGetConstant( GL_INTERLACE_READ_OML, (1,) )


def glInitInterlaceOML():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension EXT.vertex_weighting

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_EXT_vertex_weighting'
_DEPRECATED = False
GL_MODELVIEW1_STACK_DEPTH_EXT = constant.Constant( 'GL_MODELVIEW1_STACK_DEPTH_EXT', 0x8502 )
glget.addGLGetConstant( GL_MODELVIEW1_STACK_DEPTH_EXT, (1,) )
GL_MODELVIEW1_MATRIX_EXT = constant.Constant( 'GL_MODELVIEW1_MATRIX_EXT', 0x8506 )
glget.addGLGetConstant( GL_MODELVIEW1_MATRIX_EXT, (4,4) )
GL_VERTEX_WEIGHTING_EXT = constant.Constant( 'GL_VERTEX_WEIGHTING_EXT', 0x8509 )
GL_MODELVIEW1_EXT = constant.Constant( 'GL_MODELVIEW1_EXT', 0x850A )
GL_CURRENT_VERTEX_WEIGHT_EXT = constant.Constant( 'GL_CURRENT_VERTEX_WEIGHT_EXT', 0x850B )
glget.addGLGetConstant( GL_CURRENT_VERTEX_WEIGHT_EXT, (1,) )
GL_VERTEX_WEIGHT_ARRAY_EXT = constant.Constant( 'GL_VERTEX_WEIGHT_ARRAY_EXT', 0x850C )
GL_VERTEX_WEIGHT_ARRAY_SIZE_EXT = constant.Constant( 'GL_VERTEX_WEIGHT_ARRAY_SIZE_EXT', 0x850D )
glget.addGLGetConstant( GL_VERTEX_WEIGHT_ARRAY_SIZE_EXT, (1,) )
GL_VERTEX_WEIGHT_ARRAY_TYPE_EXT = constant.Constant( 'GL_VERTEX_WEIGHT_ARRAY_TYPE_EXT', 0x850E )
glget.addGLGetConstant( GL_VERTEX_WEIGHT_ARRAY_TYPE_EXT, (1,) )
GL_VERTEX_WEIGHT_ARRAY_STRIDE_EXT = constant.Constant( 'GL_VERTEX_WEIGHT_ARRAY_STRIDE_EXT', 0x850F )
glget.addGLGetConstant( GL_VERTEX_WEIGHT_ARRAY_STRIDE_EXT, (1,) )
GL_VERTEX_WEIGHT_ARRAY_POINTER_EXT = constant.Constant( 'GL_VERTEX_WEIGHT_ARRAY_POINTER_EXT', 0x8510 )
glVertexWeightfEXT = platform.createExtensionFunction( 
'glVertexWeightfEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,),
doc='glVertexWeightfEXT(GLfloat(weight)) -> None',
argNames=('weight',),
deprecated=_DEPRECATED,
)

glVertexWeightfvEXT = platform.createExtensionFunction( 
'glVertexWeightfvEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(arrays.GLfloatArray,),
doc='glVertexWeightfvEXT(GLfloatArray(weight)) -> None',
argNames=('weight',),
deprecated=_DEPRECATED,
)

glVertexWeightPointerEXT = platform.createExtensionFunction( 
'glVertexWeightPointerEXT',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glVertexWeightPointerEXT(GLsizei(size), GLenum(type), GLsizei(stride), c_void_p(pointer)) -> None',
argNames=('size','type','stride','pointer',),
deprecated=_DEPRECATED,
)


def glInitVertexWeightingEXT():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension NV.evaluators

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_NV_evaluators'
_DEPRECATED = False
GL_EVAL_2D_NV = constant.Constant( 'GL_EVAL_2D_NV', 0x86C0 )
GL_EVAL_TRIANGULAR_2D_NV = constant.Constant( 'GL_EVAL_TRIANGULAR_2D_NV', 0x86C1 )
GL_MAP_TESSELLATION_NV = constant.Constant( 'GL_MAP_TESSELLATION_NV', 0x86C2 )
GL_MAP_ATTRIB_U_ORDER_NV = constant.Constant( 'GL_MAP_ATTRIB_U_ORDER_NV', 0x86C3 )
GL_MAP_ATTRIB_V_ORDER_NV = constant.Constant( 'GL_MAP_ATTRIB_V_ORDER_NV', 0x86C4 )
GL_EVAL_FRACTIONAL_TESSELLATION_NV = constant.Constant( 'GL_EVAL_FRACTIONAL_TESSELLATION_NV', 0x86C5 )
glget.addGLGetConstant( GL_EVAL_FRACTIONAL_TESSELLATION_NV, (1,) )
GL_EVAL_VERTEX_ATTRIB0_NV = constant.Constant( 'GL_EVAL_VERTEX_ATTRIB0_NV', 0x86C6 )
glget.addGLGetConstant( GL_EVAL_VERTEX_ATTRIB0_NV, (1,) )
GL_EVAL_VERTEX_ATTRIB1_NV = constant.Constant( 'GL_EVAL_VERTEX_ATTRIB1_NV', 0x86C7 )
glget.addGLGetConstant( GL_EVAL_VERTEX_ATTRIB1_NV, (1,) )
GL_EVAL_VERTEX_ATTRIB2_NV = constant.Constant( 'GL_EVAL_VERTEX_ATTRIB2_NV', 0x86C8 )
glget.addGLGetConstant( GL_EVAL_VERTEX_ATTRIB2_NV, (1,) )
GL_EVAL_VERTEX_ATTRIB3_NV = constant.Constant( 'GL_EVAL_VERTEX_ATTRIB3_NV', 0x86C9 )
glget.addGLGetConstant( GL_EVAL_VERTEX_ATTRIB3_NV, (1,) )
GL_EVAL_VERTEX_ATTRIB4_NV = constant.Constant( 'GL_EVAL_VERTEX_ATTRIB4_NV', 0x86CA )
glget.addGLGetConstant( GL_EVAL_VERTEX_ATTRIB4_NV, (1,) )
GL_EVAL_VERTEX_ATTRIB5_NV = constant.Constant( 'GL_EVAL_VERTEX_ATTRIB5_NV', 0x86CB )
glget.addGLGetConstant( GL_EVAL_VERTEX_ATTRIB5_NV, (1,) )
GL_EVAL_VERTEX_ATTRIB6_NV = constant.Constant( 'GL_EVAL_VERTEX_ATTRIB6_NV', 0x86CC )
glget.addGLGetConstant( GL_EVAL_VERTEX_ATTRIB6_NV, (1,) )
GL_EVAL_VERTEX_ATTRIB7_NV = constant.Constant( 'GL_EVAL_VERTEX_ATTRIB7_NV', 0x86CD )
glget.addGLGetConstant( GL_EVAL_VERTEX_ATTRIB7_NV, (1,) )
GL_EVAL_VERTEX_ATTRIB8_NV = constant.Constant( 'GL_EVAL_VERTEX_ATTRIB8_NV', 0x86CE )
glget.addGLGetConstant( GL_EVAL_VERTEX_ATTRIB8_NV, (1,) )
GL_EVAL_VERTEX_ATTRIB9_NV = constant.Constant( 'GL_EVAL_VERTEX_ATTRIB9_NV', 0x86CF )
glget.addGLGetConstant( GL_EVAL_VERTEX_ATTRIB9_NV, (1,) )
GL_EVAL_VERTEX_ATTRIB10_NV = constant.Constant( 'GL_EVAL_VERTEX_ATTRIB10_NV', 0x86D0 )
glget.addGLGetConstant( GL_EVAL_VERTEX_ATTRIB10_NV, (1,) )
GL_EVAL_VERTEX_ATTRIB11_NV = constant.Constant( 'GL_EVAL_VERTEX_ATTRIB11_NV', 0x86D1 )
glget.addGLGetConstant( GL_EVAL_VERTEX_ATTRIB11_NV, (1,) )
GL_EVAL_VERTEX_ATTRIB12_NV = constant.Constant( 'GL_EVAL_VERTEX_ATTRIB12_NV', 0x86D2 )
glget.addGLGetConstant( GL_EVAL_VERTEX_ATTRIB12_NV, (1,) )
GL_EVAL_VERTEX_ATTRIB13_NV = constant.Constant( 'GL_EVAL_VERTEX_ATTRIB13_NV', 0x86D3 )
glget.addGLGetConstant( GL_EVAL_VERTEX_ATTRIB13_NV, (1,) )
GL_EVAL_VERTEX_ATTRIB14_NV = constant.Constant( 'GL_EVAL_VERTEX_ATTRIB14_NV', 0x86D4 )
glget.addGLGetConstant( GL_EVAL_VERTEX_ATTRIB14_NV, (1,) )
GL_EVAL_VERTEX_ATTRIB15_NV = constant.Constant( 'GL_EVAL_VERTEX_ATTRIB15_NV', 0x86D5 )
glget.addGLGetConstant( GL_EVAL_VERTEX_ATTRIB15_NV, (1,) )
GL_MAX_MAP_TESSELLATION_NV = constant.Constant( 'GL_MAX_MAP_TESSELLATION_NV', 0x86D6 )
glget.addGLGetConstant( GL_MAX_MAP_TESSELLATION_NV, (1,) )
GL_MAX_RATIONAL_EVAL_ORDER_NV = constant.Constant( 'GL_MAX_RATIONAL_EVAL_ORDER_NV', 0x86D7 )
glget.addGLGetConstant( GL_MAX_RATIONAL_EVAL_ORDER_NV, (1,) )
glMapControlPointsNV = platform.createExtensionFunction( 
'glMapControlPointsNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLint,constants.GLboolean,ctypes.c_void_p,),
doc='glMapControlPointsNV(GLenum(target), GLuint(index), GLenum(type), GLsizei(ustride), GLsizei(vstride), GLint(uorder), GLint(vorder), GLboolean(packed), c_void_p(points)) -> None',
argNames=('target','index','type','ustride','vstride','uorder','vorder','packed','points',),
deprecated=_DEPRECATED,
)

glMapParameterivNV = platform.createExtensionFunction( 
'glMapParameterivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glMapParameterivNV(GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glMapParameterfvNV = platform.createExtensionFunction( 
'glMapParameterfvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glMapParameterfvNV(GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glGetMapControlPointsNV = platform.createExtensionFunction( 
'glGetMapControlPointsNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLboolean,ctypes.c_void_p,),
doc='glGetMapControlPointsNV(GLenum(target), GLuint(index), GLenum(type), GLsizei(ustride), GLsizei(vstride), GLboolean(packed), c_void_p(points)) -> None',
argNames=('target','index','type','ustride','vstride','packed','points',),
deprecated=_DEPRECATED,
)

glGetMapParameterivNV = platform.createExtensionFunction( 
'glGetMapParameterivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLintArray,),
doc='glGetMapParameterivNV(GLenum(target), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glGetMapParameterfvNV = platform.createExtensionFunction( 
'glGetMapParameterfvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,arrays.GLfloatArray,),
doc='glGetMapParameterfvNV(GLenum(target), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('target','pname','params',),
deprecated=_DEPRECATED,
)

glGetMapAttribParameterivNV = platform.createExtensionFunction( 
'glGetMapAttribParameterivNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLenum,arrays.GLintArray,),
doc='glGetMapAttribParameterivNV(GLenum(target), GLuint(index), GLenum(pname), GLintArray(params)) -> None',
argNames=('target','index','pname','params',),
deprecated=_DEPRECATED,
)

glGetMapAttribParameterfvNV = platform.createExtensionFunction( 
'glGetMapAttribParameterfvNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLenum,arrays.GLfloatArray,),
doc='glGetMapAttribParameterfvNV(GLenum(target), GLuint(index), GLenum(pname), GLfloatArray(params)) -> None',
argNames=('target','index','pname','params',),
deprecated=_DEPRECATED,
)

glEvalMapsNV = platform.createExtensionFunction( 
'glEvalMapsNV',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLenum,),
doc='glEvalMapsNV(GLenum(target), GLenum(mode)) -> None',
argNames=('target','mode',),
deprecated=_DEPRECATED,
)


def glInitEvaluatorsNV():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension APPLE.transform_hint

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_APPLE_transform_hint'
_DEPRECATED = False
GL_TRANSFORM_HINT_APPLE = constant.Constant( 'GL_TRANSFORM_HINT_APPLE', 0x85B1 )


def glInitTransformHintAPPLE():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.draw_elements_base_vertex

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_ARB_draw_elements_base_vertex'
_DEPRECATED = False

glDrawElementsBaseVertex = platform.createExtensionFunction( 
'glDrawElementsBaseVertex',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,constants.GLenum,ctypes.c_void_p,constants.GLint,),
doc='glDrawElementsBaseVertex(GLenum(mode), GLsizei(count), GLenum(type), c_void_p(indices), GLint(basevertex)) -> None',
argNames=('mode','count','type','indices','basevertex',),
deprecated=_DEPRECATED,
)

glDrawRangeElementsBaseVertex = platform.createExtensionFunction( 
'glDrawRangeElementsBaseVertex',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLuint,constants.GLuint,constants.GLsizei,constants.GLenum,ctypes.c_void_p,constants.GLint,),
doc='glDrawRangeElementsBaseVertex(GLenum(mode), GLuint(start), GLuint(end), GLsizei(count), GLenum(type), c_void_p(indices), GLint(basevertex)) -> None',
argNames=('mode','start','end','count','type','indices','basevertex',),
deprecated=_DEPRECATED,
)

glDrawElementsInstancedBaseVertex = platform.createExtensionFunction( 
'glDrawElementsInstancedBaseVertex',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLsizei,constants.GLenum,ctypes.c_void_p,constants.GLsizei,constants.GLint,),
doc='glDrawElementsInstancedBaseVertex(GLenum(mode), GLsizei(count), GLenum(type), c_void_p(indices), GLsizei(primcount), GLint(basevertex)) -> None',
argNames=('mode','count','type','indices','primcount','basevertex',),
deprecated=_DEPRECATED,
)

glMultiDrawElementsBaseVertex = platform.createExtensionFunction( 
'glMultiDrawElementsBaseVertex',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,arrays.GLsizeiArray,constants.GLenum,ctypes.POINTER(ctypes.c_void_p),constants.GLsizei,arrays.GLintArray,),
doc='glMultiDrawElementsBaseVertex(GLenum(mode), GLsizeiArray(count), GLenum(type), POINTER(ctypes.c_void_p)(indices), GLsizei(primcount), GLintArray(basevertex)) -> None',
argNames=('mode','count','type','indices','primcount','basevertex',),
deprecated=_DEPRECATED,
)


def glInitDrawElementsBaseVertexARB():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension ARB.multitexture

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.multitexture to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/multitexture.txt
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions, wrapper
from OpenGL.GL import glget
import ctypes
from OpenGL.raw.GL.ARB.multitexture import *
### END AUTOGENERATED SECTION
for typ,arrayType in (
    ('d',arrays.GLdoubleArray),
    ('f',arrays.GLfloatArray),
    ('i',arrays.GLintArray),
    ('s',arrays.GLshortArray),
):
    for size in (1,2,3,4):
        name = 'glMultiTexCoord%(size)s%(typ)svARB'%globals()
        globals()[name] = arrays.setInputArraySizeType(
            globals()[name],
            size,
            arrayType, 
            'v',
        )
        del size,name
    del typ,arrayType


'''OpenGL extension AMD.vertex_shader_tesselator

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_AMD_vertex_shader_tesselator'
_DEPRECATED = False
GL_SAMPLER_BUFFER_AMD = constant.Constant( 'GL_SAMPLER_BUFFER_AMD', 0x9001 )
GL_INT_SAMPLER_BUFFER_AMD = constant.Constant( 'GL_INT_SAMPLER_BUFFER_AMD', 0x9002 )
GL_UNSIGNED_INT_SAMPLER_BUFFER_AMD = constant.Constant( 'GL_UNSIGNED_INT_SAMPLER_BUFFER_AMD', 0x9003 )
GL_TESSELLATION_MODE_AMD = constant.Constant( 'GL_TESSELLATION_MODE_AMD', 0x9004 )
GL_TESSELLATION_FACTOR_AMD = constant.Constant( 'GL_TESSELLATION_FACTOR_AMD', 0x9005 )
GL_DISCRETE_AMD = constant.Constant( 'GL_DISCRETE_AMD', 0x9006 )
GL_CONTINUOUS_AMD = constant.Constant( 'GL_CONTINUOUS_AMD', 0x9007 )
glTessellationFactorAMD = platform.createExtensionFunction( 
'glTessellationFactorAMD',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLfloat,),
doc='glTessellationFactorAMD(GLfloat(factor)) -> None',
argNames=('factor',),
deprecated=_DEPRECATED,
)

glTessellationModeAMD = platform.createExtensionFunction( 
'glTessellationModeAMD',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glTessellationModeAMD(GLenum(mode)) -> None',
argNames=('mode',),
deprecated=_DEPRECATED,
)


def glInitVertexShaderTesselatorAMD():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension VERSION.GL_1_3

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_VERSION_GL_1_3'
_DEPRECATED = False
GL_TEXTURE0 = constant.Constant( 'GL_TEXTURE0', 0x84C0 )
GL_TEXTURE1 = constant.Constant( 'GL_TEXTURE1', 0x84C1 )
GL_TEXTURE2 = constant.Constant( 'GL_TEXTURE2', 0x84C2 )
GL_TEXTURE3 = constant.Constant( 'GL_TEXTURE3', 0x84C3 )
GL_TEXTURE4 = constant.Constant( 'GL_TEXTURE4', 0x84C4 )
GL_TEXTURE5 = constant.Constant( 'GL_TEXTURE5', 0x84C5 )
GL_TEXTURE6 = constant.Constant( 'GL_TEXTURE6', 0x84C6 )
GL_TEXTURE7 = constant.Constant( 'GL_TEXTURE7', 0x84C7 )
GL_TEXTURE8 = constant.Constant( 'GL_TEXTURE8', 0x84C8 )
GL_TEXTURE9 = constant.Constant( 'GL_TEXTURE9', 0x84C9 )
GL_TEXTURE10 = constant.Constant( 'GL_TEXTURE10', 0x84CA )
GL_TEXTURE11 = constant.Constant( 'GL_TEXTURE11', 0x84CB )
GL_TEXTURE12 = constant.Constant( 'GL_TEXTURE12', 0x84CC )
GL_TEXTURE13 = constant.Constant( 'GL_TEXTURE13', 0x84CD )
GL_TEXTURE14 = constant.Constant( 'GL_TEXTURE14', 0x84CE )
GL_TEXTURE15 = constant.Constant( 'GL_TEXTURE15', 0x84CF )
GL_TEXTURE16 = constant.Constant( 'GL_TEXTURE16', 0x84D0 )
GL_TEXTURE17 = constant.Constant( 'GL_TEXTURE17', 0x84D1 )
GL_TEXTURE18 = constant.Constant( 'GL_TEXTURE18', 0x84D2 )
GL_TEXTURE19 = constant.Constant( 'GL_TEXTURE19', 0x84D3 )
GL_TEXTURE20 = constant.Constant( 'GL_TEXTURE20', 0x84D4 )
GL_TEXTURE21 = constant.Constant( 'GL_TEXTURE21', 0x84D5 )
GL_TEXTURE22 = constant.Constant( 'GL_TEXTURE22', 0x84D6 )
GL_TEXTURE23 = constant.Constant( 'GL_TEXTURE23', 0x84D7 )
GL_TEXTURE24 = constant.Constant( 'GL_TEXTURE24', 0x84D8 )
GL_TEXTURE25 = constant.Constant( 'GL_TEXTURE25', 0x84D9 )
GL_TEXTURE26 = constant.Constant( 'GL_TEXTURE26', 0x84DA )
GL_TEXTURE27 = constant.Constant( 'GL_TEXTURE27', 0x84DB )
GL_TEXTURE28 = constant.Constant( 'GL_TEXTURE28', 0x84DC )
GL_TEXTURE29 = constant.Constant( 'GL_TEXTURE29', 0x84DD )
GL_TEXTURE30 = constant.Constant( 'GL_TEXTURE30', 0x84DE )
GL_TEXTURE31 = constant.Constant( 'GL_TEXTURE31', 0x84DF )
GL_ACTIVE_TEXTURE = constant.Constant( 'GL_ACTIVE_TEXTURE', 0x84E0 )
GL_MULTISAMPLE = constant.Constant( 'GL_MULTISAMPLE', 0x809D )
GL_SAMPLE_ALPHA_TO_COVERAGE = constant.Constant( 'GL_SAMPLE_ALPHA_TO_COVERAGE', 0x809E )
GL_SAMPLE_ALPHA_TO_ONE = constant.Constant( 'GL_SAMPLE_ALPHA_TO_ONE', 0x809F )
GL_SAMPLE_COVERAGE = constant.Constant( 'GL_SAMPLE_COVERAGE', 0x80A0 )
GL_SAMPLE_BUFFERS = constant.Constant( 'GL_SAMPLE_BUFFERS', 0x80A8 )
GL_SAMPLES = constant.Constant( 'GL_SAMPLES', 0x80A9 )
GL_SAMPLE_COVERAGE_VALUE = constant.Constant( 'GL_SAMPLE_COVERAGE_VALUE', 0x80AA )
GL_SAMPLE_COVERAGE_INVERT = constant.Constant( 'GL_SAMPLE_COVERAGE_INVERT', 0x80AB )
GL_TEXTURE_CUBE_MAP = constant.Constant( 'GL_TEXTURE_CUBE_MAP', 0x8513 )
GL_TEXTURE_BINDING_CUBE_MAP = constant.Constant( 'GL_TEXTURE_BINDING_CUBE_MAP', 0x8514 )
GL_TEXTURE_CUBE_MAP_POSITIVE_X = constant.Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_X', 0x8515 )
GL_TEXTURE_CUBE_MAP_NEGATIVE_X = constant.Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_X', 0x8516 )
GL_TEXTURE_CUBE_MAP_POSITIVE_Y = constant.Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_Y', 0x8517 )
GL_TEXTURE_CUBE_MAP_NEGATIVE_Y = constant.Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Y', 0x8518 )
GL_TEXTURE_CUBE_MAP_POSITIVE_Z = constant.Constant( 'GL_TEXTURE_CUBE_MAP_POSITIVE_Z', 0x8519 )
GL_TEXTURE_CUBE_MAP_NEGATIVE_Z = constant.Constant( 'GL_TEXTURE_CUBE_MAP_NEGATIVE_Z', 0x851A )
GL_PROXY_TEXTURE_CUBE_MAP = constant.Constant( 'GL_PROXY_TEXTURE_CUBE_MAP', 0x851B )
GL_MAX_CUBE_MAP_TEXTURE_SIZE = constant.Constant( 'GL_MAX_CUBE_MAP_TEXTURE_SIZE', 0x851C )
GL_COMPRESSED_RGB = constant.Constant( 'GL_COMPRESSED_RGB', 0x84ED )
GL_COMPRESSED_RGBA = constant.Constant( 'GL_COMPRESSED_RGBA', 0x84EE )
GL_TEXTURE_COMPRESSION_HINT = constant.Constant( 'GL_TEXTURE_COMPRESSION_HINT', 0x84EF )
GL_TEXTURE_COMPRESSED_IMAGE_SIZE = constant.Constant( 'GL_TEXTURE_COMPRESSED_IMAGE_SIZE', 0x86A0 )
GL_TEXTURE_COMPRESSED = constant.Constant( 'GL_TEXTURE_COMPRESSED', 0x86A1 )
GL_NUM_COMPRESSED_TEXTURE_FORMATS = constant.Constant( 'GL_NUM_COMPRESSED_TEXTURE_FORMATS', 0x86A2 )
GL_COMPRESSED_TEXTURE_FORMATS = constant.Constant( 'GL_COMPRESSED_TEXTURE_FORMATS', 0x86A3 )
GL_CLAMP_TO_BORDER = constant.Constant( 'GL_CLAMP_TO_BORDER', 0x812D )
glActiveTexture = platform.createExtensionFunction( 
'glActiveTexture',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,),
doc='glActiveTexture(GLenum(texture)) -> None',
argNames=('texture',),
deprecated=_DEPRECATED,
)

glSampleCoverage = platform.createExtensionFunction( 
'glSampleCoverage',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLclampf,constants.GLboolean,),
doc='glSampleCoverage(GLclampf(value), GLboolean(invert)) -> None',
argNames=('value','invert',),
deprecated=_DEPRECATED,
)

glCompressedTexImage3D = platform.createExtensionFunction( 
'glCompressedTexImage3D',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTexImage3D(GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLsizei(depth), GLint(border), GLsizei(imageSize), c_void_p(data)) -> None',
argNames=('target','level','internalformat','width','height','depth','border','imageSize','data',),
deprecated=_DEPRECATED,
)

glCompressedTexImage2D = platform.createExtensionFunction( 
'glCompressedTexImage2D',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLsizei,constants.GLint,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTexImage2D(GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLsizei(height), GLint(border), GLsizei(imageSize), c_void_p(data)) -> None',
argNames=('target','level','internalformat','width','height','border','imageSize','data',),
deprecated=_DEPRECATED,
)

glCompressedTexImage1D = platform.createExtensionFunction( 
'glCompressedTexImage1D',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLenum,constants.GLsizei,constants.GLint,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTexImage1D(GLenum(target), GLint(level), GLenum(internalformat), GLsizei(width), GLint(border), GLsizei(imageSize), c_void_p(data)) -> None',
argNames=('target','level','internalformat','width','border','imageSize','data',),
deprecated=_DEPRECATED,
)

glCompressedTexSubImage3D = platform.createExtensionFunction( 
'glCompressedTexSubImage3D',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTexSubImage3D(GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLint(zoffset), GLsizei(width), GLsizei(height), GLsizei(depth), GLenum(format), GLsizei(imageSize), c_void_p(data)) -> None',
argNames=('target','level','xoffset','yoffset','zoffset','width','height','depth','format','imageSize','data',),
deprecated=_DEPRECATED,
)

glCompressedTexSubImage2D = platform.createExtensionFunction( 
'glCompressedTexSubImage2D',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLint,constants.GLsizei,constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTexSubImage2D(GLenum(target), GLint(level), GLint(xoffset), GLint(yoffset), GLsizei(width), GLsizei(height), GLenum(format), GLsizei(imageSize), c_void_p(data)) -> None',
argNames=('target','level','xoffset','yoffset','width','height','format','imageSize','data',),
deprecated=_DEPRECATED,
)

glCompressedTexSubImage1D = platform.createExtensionFunction( 
'glCompressedTexSubImage1D',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,constants.GLint,constants.GLsizei,constants.GLenum,constants.GLsizei,ctypes.c_void_p,),
doc='glCompressedTexSubImage1D(GLenum(target), GLint(level), GLint(xoffset), GLsizei(width), GLenum(format), GLsizei(imageSize), c_void_p(data)) -> None',
argNames=('target','level','xoffset','width','format','imageSize','data',),
deprecated=_DEPRECATED,
)

glGetCompressedTexImage = platform.createExtensionFunction( 
'glGetCompressedTexImage',dll=platform.GL,
extension=EXTENSION_NAME,
resultType=None, 
argTypes=(constants.GLenum,constants.GLint,ctypes.c_void_p,),
doc='glGetCompressedTexImage(GLenum(target), GLint(level), c_void_p(img)) -> None',
argNames=('target','level','img',),
deprecated=_DEPRECATED,
)
# import legacy entry points to allow checking for bool(entryPoint)
from OpenGL.raw.GL.VERSION.GL_1_3_DEPRECATED import *



import OpenGL.GL as gl
import OpenGL.images as images

def test_createTargetArray():
    size = (640,480)
    array1 = images.createTargetArray( gl.GL_BGRA, size, gl.GL_UNSIGNED_INT_8_8_8_8_REV)
    array2 = images.createTargetArray( gl.GL_RGBA, size, gl.GL_UNSIGNED_BYTE)
    array3 = images.createTargetArray( gl.GL_RGBA, size, gl.GL_UNSIGNED_INT_8_8_8_8_REV)
    assert array1.nbytes == array3.nbytes
    assert array1.nbytes == array2.nbytes
    
    try:
        images.createTargetArray( gl.GL_RGBA, size, gl.GL_UNSIGNED_BYTE_3_3_2 )
    except ValueError, err:
        pass 
    else:
        raise RuntimeError( """Should have failed with insufficient components in the type to hold the format""" )


'''OpenGL extension SGIX.texture_coordinate_clamp

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_texture_coordinate_clamp'
_DEPRECATED = False
GL_TEXTURE_MAX_CLAMP_S_SGIX = constant.Constant( 'GL_TEXTURE_MAX_CLAMP_S_SGIX', 0x8369 )
GL_TEXTURE_MAX_CLAMP_T_SGIX = constant.Constant( 'GL_TEXTURE_MAX_CLAMP_T_SGIX', 0x836A )
GL_TEXTURE_MAX_CLAMP_R_SGIX = constant.Constant( 'GL_TEXTURE_MAX_CLAMP_R_SGIX', 0x836B )


def glInitTextureCoordinateClampSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )



'''OpenGL extension SGIX.texture_multi_buffer

Automatically generated by the get_gl_extensions script, do not edit!
'''
from OpenGL import platform, constants, constant, arrays
from OpenGL import extensions
from OpenGL.GL import glget
import ctypes
EXTENSION_NAME = 'GL_SGIX_texture_multi_buffer'
_DEPRECATED = False
GL_TEXTURE_MULTI_BUFFER_HINT_SGIX = constant.Constant( 'GL_TEXTURE_MULTI_BUFFER_HINT_SGIX', 0x812E )


def glInitTextureMultiBufferSGIX():
    '''Return boolean indicating whether this extension is available'''
    return extensions.hasGLExtension( EXTENSION_NAME )
